@@ -37,7 +37,7 @@
 
 
 /////////////////////// Local includes
-#include "Atom.hpp"
+#include <libmass/Atom.hpp>
 
 
 namespace msXpSlibmass
