@@ -37,7 +37,7 @@
 
 
 /////////////////////// Local includes
-#include "Formula.hpp"
+#include <libmass/Formula.hpp>
 
 
 namespace msXpSlibmass
