@@ -66,7 +66,7 @@
 using namespace std;
 
 /////////////////////// Local includes
-#include "IsotopicPatternCalculator.hpp"
+#include <libmass/IsotopicPatternCalculator.hpp>
 
 
 namespace msXpSlibmass
