@@ -28,7 +28,7 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  * 
  * END software license
-*/
+ */
 
 
 
@@ -38,12 +38,16 @@
 #include <QScriptEngine>
 #include <QListWidget>
 #include <QDebug>
+#include <QFileDialog>
 
 
 ///////////////////////////// Local includes
-#include "globals/globals.hpp"
-#include "ScriptingWnd.hpp"
-#include "ScriptingObjectTreeWidgetItem.hpp"
+#include <globals/globals.hpp>
+#include <libmassgui/ScriptingWnd.hpp>
+#include <libmassgui/ScriptingObjectTreeWidgetItem.hpp>
+#include <libmass/DataPointJs.hpp>
+#include <libmass/TraceJs.hpp>
+#include <libmass/MassSpectrumJs.hpp>
 
 
 namespace msXpSlibmassgui
@@ -125,30 +129,83 @@ namespace msXpSlibmassgui
 		m_ui.historyListWidget->setSelectionMode(QAbstractItemView::ExtendedSelection);
 		m_ui.historyListWidget->setVerticalScrollMode(QAbstractItemView::ScrollPerItem);
 
+		// Create the menu and menu items.
+
+		// File menu
+		mp_fileMenu = menuBar()->addMenu("&File");
+
+		mp_runScriptFileAct = new QAction(tr("&Run a JavaScript from file"),
+				dynamic_cast<QObject *>(this));
+		mp_runScriptFileAct->setShortcut(QKeySequence("Ctrl+O, F"));
+		mp_runScriptFileAct->setStatusTip(
+				tr("Run a JavaScript"));
+
+		connect(mp_runScriptFileAct, SIGNAL(triggered()), 
+				this, SLOT(runScriptFile()));
+
+		mp_fileMenu->addAction(mp_runScriptFileAct);
+
 		readSettings();
 
+		// Make sure we can convert QList<double> to script value:
+		qScriptRegisterSequenceMetaType<QList<double>>(&m_scriptEngine);	
+
+		/// We'll need these strings many times.
+		QString result;
+		QString help;
+
 		// We want to provide the user with a print() function that is not available
 		// in ECMAScript.
 
 		QScriptValue function = m_scriptEngine.newFunction(print);
-
-		// So that we can later, in the localPrint function ask for the ScriptingWnd
-		// object where we will call logOutTextEdit().
-
 		function.setData(m_scriptEngine.newQObject(this));
-
-		// Make the function available under js function name "print".
 		m_scriptEngine.globalObject().setProperty("print", function);
 
+		help = QString("JavaScript has no print() function, we provide one.\n"
+				"Run it like this: print(<object>)");
+
+		publishEntityWithScriptValue(function,
+				this,
+				"print()",
+				"",
+				"Make available the function print() to print object data",
+				help,
+				ScriptEntityType::FunctionEntity,
+				&result);
 
-		// We want to provide the user with a printToFile() function that is not available
-		// in ECMAScript.
 
 		function = m_scriptEngine.newFunction(printToFile);
-
-		// Make the function available under js function name "print".
+		function.setData(m_scriptEngine.newQObject(this));
 		m_scriptEngine.globalObject().setProperty("printToFile", function);
+
+		help = QString("JavaScript has no printToFile() function, we provide one.\n"
+				"Run it like this: printToFile(<object>, <fileName>).\n"
+				"For example: printToFile(t1, \"/tmp/trial.txt\").");
+
+		publishEntityWithScriptValue(function,
+				this,
+				"printToFile()",
+				"",
+				"Make available the function printToFile() to print object data to a file",
+				help,
+				ScriptEntityType::FunctionEntity,
+				&result);
+
+
+		// Make sure we make the DataPoint class available to the script environment.
+		msXpSlibmass::DataPointJs *dataPointJs= new msXpSlibmass::DataPointJs(&m_scriptEngine);
+		m_scriptEngine.globalObject().setProperty("DataPoint", dataPointJs->constructor());	
+
+		// Make sure we make the Trace class available to the script environment.
+		msXpSlibmass::TraceJs *traceJs= new msXpSlibmass::TraceJs(&m_scriptEngine);
+		m_scriptEngine.globalObject().setProperty("Trace", traceJs->constructor());	
+
+		// Make sure we make the MassSpectrum class available to the script environment.
+		msXpSlibmass::MassSpectrumJs *massSpectrumJs= new msXpSlibmass::MassSpectrumJs(&m_scriptEngine);
+		m_scriptEngine.globalObject().setProperty("MassSpectrum", massSpectrumJs->constructor());	
+
 		show();
+
 	}
 
 
@@ -867,6 +924,20 @@ namespace msXpSlibmassgui
 		}	
 
 
+	void
+		ScriptingWnd::showHistory()
+		{
+
+			QList<QWidget *> widgetList = m_ui.tabWidget->findChildren<QWidget *>("historyTab");
+			if(widgetList.isEmpty())
+				qFatal("Fatal error at %s@%d -- %s(). "
+						"Cannot be that no history tab be found."
+						"Program aborted.",
+						__FILE__, __LINE__, __FUNCTION__);
+
+			m_ui.tabWidget->setCurrentWidget(widgetList.first());
+		}
+
 	QString 
 		ScriptingWnd::historyAsString(bool colorTagged, const QString &lineSeparator)
 		{
@@ -916,7 +987,7 @@ namespace msXpSlibmassgui
 				// object pointer. If so, make the new object's widget item a child of
 				// the parent's one.
 
-				parentWidgetItem = getObjetTreeWidgetItemByQObject(parent);
+				parentWidgetItem = getObjectTreeWidgetItemByQObject(parent);
 			}
 
 			// We do not want to create the new item, with alias, if there is an alias
@@ -983,7 +1054,8 @@ namespace msXpSlibmassgui
 
 
 	bool 
-		ScriptingWnd::publishEntity(QString script, 
+		ScriptingWnd::publishEntityWithScript(QString script, 
+				QObject *parent,
 				const QString &jsName,
 				const QString &alias, 
 				const QString &comment, 
@@ -991,6 +1063,13 @@ namespace msXpSlibmassgui
 				ScriptEntityType entityType,
 				QString *result)
 		{
+			if(result == Q_NULLPTR)
+				qFatal("Fatal error at %s@%d -- %s(). "
+						"Pointer cannot be nullptr."
+						"Program aborted.",
+						__FILE__, __LINE__, __FUNCTION__);
+
+			// First of all run the script and go on only if the returned value is ok.
 			bool ok = runScript(script, comment, result);
 
 			if(!ok)
@@ -999,10 +1078,128 @@ namespace msXpSlibmassgui
 			// Now use the js name of the object to insert a new element in the
 			// script environment tree widget.
 
-			QTreeWidgetItem *treeWidgetItem = new QTreeWidgetItem(m_ui.objectTreeWidget);
-			treeWidgetItem->setText(ObjectTreeWidgetColumn::Name, jsName);
+			// But, create a hierarchy, if possible: if parent is non-nullptr, then
+			// make the new item a child of parent->item.
+			// 
+			// Note that, if an alias was provided, we will add it also.
+
+			ScriptingObjectTreeWidgetItem *newTreeWidgetItem = Q_NULLPTR;
+			ScriptingObjectTreeWidgetItem *parentWidgetItem = Q_NULLPTR;
+
+			if(parent != Q_NULLPTR)
+			{
+
+				// We are provided a QObject * as parent of the new one, so search in
+				// the object tree widget if there is an item that has that parent
+				// object pointer. If so, make the new object's widget item a child of
+				// the parent's one.
+
+				parentWidgetItem = getObjectTreeWidgetItemByQObject(parent);
+			}
+
+			// We do not want to create the new item, with alias, if there is an alias
+			// in this function call and there might be one that we must first erase.
+
 			if(!alias.isEmpty())
-				treeWidgetItem->setText(ObjectTreeWidgetColumn::Alias, alias);
+			{
+
+				// Create the alias object.
+
+				m_scriptEngine.globalObject().setProperty(alias, jsName);
+			}
+
+			// We can go on with the creation of the new widget item.
+
+			if(parentWidgetItem != Q_NULLPTR)
+			{
+				newTreeWidgetItem = 
+					new ScriptingObjectTreeWidgetItem(parentWidgetItem, QTreeWidgetItem::ItemType::Type);
+			}
+			else
+			{
+				newTreeWidgetItem = 
+					new ScriptingObjectTreeWidgetItem(m_ui.objectTreeWidget, QTreeWidgetItem::ItemType::Type);
+			}
+
+			newTreeWidgetItem->setText(ObjectTreeWidgetColumn::Name, jsName);
+			newTreeWidgetItem->setText(ObjectTreeWidgetColumn::Alias, alias);
+
+			newTreeWidgetItem->setProperties(Q_NULLPTR, comment, help, entityType);
+
+			if(!comment.isEmpty())
+				logOutTextEdit(QString("%1%2").arg(m_commentPrefix).arg(comment), LogTextColor::Comment);	
+
+			return true;
+		}
+
+
+
+	bool 
+		ScriptingWnd::publishEntityWithScriptValue(QScriptValue scriptValue, 
+				QObject *parent,
+				const QString &jsName,
+				const QString &alias, 
+				const QString &comment, 
+				const QString &help,
+				ScriptEntityType entityType,
+				QString *result)
+		{
+			if(result == Q_NULLPTR)
+				qFatal("Fatal error at %s@%d -- %s(). "
+						"Pointer cannot be nullptr."
+						"Program aborted.",
+						__FILE__, __LINE__, __FUNCTION__);
+
+			// Now use the js name of the object to insert a new element in the
+			// script environment tree widget.
+
+			// But, create a hierarchy, if possible: if parent is non-nullptr, then
+			// make the new item a child of parent->item.
+			// 
+			// Note that, if an alias was provided, we will add it also.
+
+			ScriptingObjectTreeWidgetItem *newTreeWidgetItem = Q_NULLPTR;
+			ScriptingObjectTreeWidgetItem *parentWidgetItem = Q_NULLPTR;
+
+			if(parent != Q_NULLPTR)
+			{
+
+				// We are provided a QObject * as parent of the new one, so search in
+				// the object tree widget if there is an item that has that parent
+				// object pointer. If so, make the new object's widget item a child of
+				// the parent's one.
+
+				parentWidgetItem = getObjectTreeWidgetItemByQObject(parent);
+			}
+
+			// We do not want to create the new item, with alias, if there is an alias
+			// in this function call and there might be one that we must first erase.
+
+			if(!alias.isEmpty())
+			{
+
+				// Create the alias object.
+
+				m_scriptEngine.globalObject().setProperty(alias, jsName);
+			}
+
+			// We can go on with the creation of the new widget item.
+
+			if(parentWidgetItem != Q_NULLPTR)
+			{
+				newTreeWidgetItem = 
+					new ScriptingObjectTreeWidgetItem(parentWidgetItem, QTreeWidgetItem::ItemType::Type);
+			}
+			else
+			{
+				newTreeWidgetItem = 
+					new ScriptingObjectTreeWidgetItem(m_ui.objectTreeWidget, QTreeWidgetItem::ItemType::Type);
+			}
+
+			newTreeWidgetItem->setText(ObjectTreeWidgetColumn::Name, jsName);
+			newTreeWidgetItem->setText(ObjectTreeWidgetColumn::Alias, alias);
+
+			newTreeWidgetItem->setProperties(Q_NULLPTR, comment, help, entityType);
 
 			if(!comment.isEmpty())
 				logOutTextEdit(QString("%1%2").arg(m_commentPrefix).arg(comment), LogTextColor::Comment);	
@@ -1012,7 +1209,7 @@ namespace msXpSlibmassgui
 
 
 	ScriptingObjectTreeWidgetItem *
-		ScriptingWnd::getObjetTreeWidgetItemByQObject(QObject *parent)
+		ScriptingWnd::getObjectTreeWidgetItemByQObject(QObject *parent)
 		{
 			QTreeWidgetItemIterator iterator(m_ui.objectTreeWidget);
 			while(*iterator) 
@@ -1112,6 +1309,7 @@ namespace msXpSlibmassgui
 			}
 		}
 
+
 	void 
 		ScriptingWnd::publishedQObjectDestroyed(QObject *object)
 		{
@@ -1135,6 +1333,64 @@ namespace msXpSlibmassgui
 		}
 
 
+	void 
+		ScriptingWnd::loadScriptFile(const QString &fileName)
+		{
+			return runScriptFile(fileName);
+		}
+
+
+	void 
+		ScriptingWnd::runScriptFile(const QString &fileName)
+		{
+			QString scriptFileName = fileName;
+
+			if(scriptFileName.isEmpty())
+			{
+
+				QFileDialog fileDialog(this);
+				fileDialog.setFileMode(QFileDialog::ExistingFile);
+				fileDialog.setViewMode(QFileDialog::Detail);
+				fileDialog.setAcceptMode(QFileDialog::AcceptOpen);
+				fileDialog.setDirectory(QDir::home());
+
+				QStringList fileNames;
+
+				if(fileDialog.exec())
+				{
+					scriptFileName = fileDialog.selectedFiles().first();
+				}
+				else
+					return;
+			}
+
+			QFile file(scriptFileName);
+
+			if(!file.open(QFile::ReadOnly | QFile::Text))
+				return;
+
+			QTextStream stream(&file);
+			QString *mp_scriptContents = new QString(stream.readAll());
+
+			if(mp_scriptContents != Q_NULLPTR && !mp_scriptContents->isEmpty())
+			{
+				//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ 
+				//<< "The script file contents: " << *mp_scriptContents;
+
+				file.close();
+
+				QString explanation = QString("Running script from file %1\n")
+					.arg(fileName);
+
+				runScript(*mp_scriptContents, explanation);
+
+				delete mp_scriptContents;
+			}
+
+			file.close();
+		}
+
+
 	QColor 
 		ScriptingWnd::logColor(LogTextColor contextColor)
 		{
@@ -1294,9 +1550,6 @@ namespace msXpSlibmassgui
 				const QString &comment, QString *result)
 		{
 
-			//qInfo() << __FILE__ << __LINE__
-			//<< "Should run script:" << script;
-
 			// If there is an explanatory comment to this script command, then start
 			// by logging it, so that it precedes the result output in the
 			// logOutTextEdit widget.
@@ -1304,33 +1557,68 @@ namespace msXpSlibmassgui
 			if(!comment.isEmpty())
 				logOutTextEdit(QString("%1%2").arg(m_commentPrefix).arg(comment), LogTextColor::Comment);
 
-			QScriptValue value = m_scriptEngine.evaluate(script);
+			QString scriptElement;
+			QStringList scriptElements = script.split(QRegularExpression("(\\s*;\\s*|\\s*\n)"), QString::SkipEmptyParts);
+
+			bool scriptsFailed = false;
+
+			if(scriptElements.size() > 1)
+			{
+				qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()" 
+					<< "scriptElements size:" << scriptElements.size();
+
+				for(int iter = 0; iter < scriptElements.size(); ++iter)
+				{
+					bool success = false;
+
+					// We do not want to duplicate the comment for each script element. So
+					// we pass QString() below.
+
+					success = runScript(scriptElements.at(iter), QString(), result);
+
+					if(!success)
+						scriptsFailed = true;
+				}
+
+				return !scriptsFailed;
+			}
+
+			if(scriptElements.size() == 0)
+				scriptElement = script;
+			else
+				scriptElement = scriptElements.first();
+
+			qDebug() << __FILE__ << __LINE__
+				<< "Should run unitary script:" << scriptElement;
+
+			QScriptValue value = m_scriptEngine.evaluate(scriptElement);
 
 			bool scriptFailed = value.isError();
 
 			if(scriptFailed)
 			{
 				// red color.
-				logOutTextEdit(value.toString() + ".\n", LogTextColor::Failure);
+				logOutTextEdit(value.toString() + "\n", LogTextColor::Failure);
 
 				if(m_historyLoggingType & HistoryLoggingType::OnFailure)
-					logHistory(script, LogTextColor::Failure);
+					logHistory(scriptElement + ";", LogTextColor::Failure);
 			}
 			else if(value.isUndefined())
 			{
 				// black color;
-				logOutTextEdit(value.toString() + ".\n", LogTextColor::Undefined);
+				logOutTextEdit(value.toString() + "\n", LogTextColor::Undefined);
 
 				if(m_historyLoggingType & HistoryLoggingType::OnSuccess)
-					logHistory(script, LogTextColor::Undefined);
+					logHistory(scriptElement + ";", LogTextColor::Undefined);
 			}
 			else
 			{
 				// green color.
-				logOutTextEdit(value.toString() + ".\n", LogTextColor::Success);
+				logOutTextEdit(value.toString() + "\n", LogTextColor::Success);
 
 				if(m_historyLoggingType & HistoryLoggingType::OnSuccess)
-					logHistory(script, LogTextColor::Success);
+					// Make sure we put back the ';' because we want it in the history items.
+					logHistory(scriptElement + ";", LogTextColor::Success);
 			}
 
 			// When a command has been run, whatever its result, we remove it from the
@@ -1340,7 +1628,7 @@ namespace msXpSlibmassgui
 			m_ui.inTextEdit->clear();
 
 			if(result != Q_NULLPTR)
-				*result = value.toString();
+				result->append(value.toString());
 
 			return !scriptFailed;
 		}
