@@ -78,9 +78,10 @@ namespace msXpSmassXpert
 					"<li>Powerful mass search in a polymer sequence with associated ion charge values ranges;</li>\n"
 					"<li>Powerful Copy/Paste paradigm allowing the pasted polymer sequence to be purified;</li>\n"
 					"<li>Calculation of isotopic pattern of any chemical starting from a formula.</li>\n"
+					"<li>Spectrum generation on the basis of polymer digestion products.</li>\n"
 					"</ul>\n"
 					"<br>\n"
-					"Visit http://www.massxpert.org\n"
+					"Visit http://www.msxpertsuite.org or https://salsa.debian.org/lopippo/msXpertSuite.\n"
 					"</body></html>\n");
 		}
 
