@@ -38,10 +38,10 @@
 
 
 /////////////////////// Local includes
-#include "AtomDefDlg.hpp"
-#include "PolChemDef.hpp"
-#include "PolChemDefWnd.hpp"
-#include "libmass/Isotope.hpp"
+#include <massxpert/gui/AtomDefDlg.hpp>
+#include <massxpert/nongui/PolChemDef.hpp>
+#include <massxpert/gui/PolChemDefWnd.hpp>
+#include <libmass/Isotope.hpp>
 
 
 namespace msXpSmassXpert
