@@ -40,14 +40,14 @@
 #include<QMessageBox>
 
 /////////////////////// Local includes
-#include "CalculatorWnd.hpp"
-#include "MainWindow.hpp"
-#include "CalculatorRecorderDlg.hpp"
-#include "PolChemDefEntity.hpp"
-#include "Sequence.hpp"
-#include "MzCalculationDlg.hpp"
-#include "SpectrumCalculationDlg.hpp"
-#include "ConfigSetting.hpp"
+#include <massxpert/gui/CalculatorWnd.hpp>
+#include <massxpert/gui/MainWindow.hpp>
+#include <massxpert/gui/CalculatorRecorderDlg.hpp>
+#include <massxpert/nongui/PolChemDefEntity.hpp>
+#include <massxpert/nongui/Sequence.hpp>
+#include <massxpert/gui/MzCalculationDlg.hpp>
+#include <massxpert/gui/SpectrumCalculationDlg.hpp>
+#include <massxpert/nongui/ConfigSetting.hpp>
 
 
 namespace msXpSmassXpert
