@@ -40,13 +40,13 @@
 
 
 /////////////////////// Local includes
-#include "CleavageDlg.hpp"
+#include <massxpert/gui/CleavageDlg.hpp>
 
-#include "libmass/PeakShape.hpp"
-#include "libmass/PeakCentroid.hpp"
-#include "libmass/PeakShapeConfig.hpp"
-#include "libmass/IsotopicPatternCalculator.hpp"
-#include "SpectrumCalculationDlg.hpp"
+#include <libmass/PeakShape.hpp>
+#include <libmass/PeakCentroid.hpp>
+#include <libmass/PeakShapeConfig.hpp>
+#include <libmass/IsotopicPatternCalculator.hpp>
+#include <massxpert/gui/SpectrumCalculationDlg.hpp>
 
 
 namespace msXpSmassXpert
