@@ -39,12 +39,12 @@
 #include <QDrag>
 #include<QDebug>
 #include<QMouseEvent>
-#include<QMessageBox> /////////////////////// Local includes #include "globals.hpp"
-#include "CleaveOligomerTableView.hpp"
-#include "CleaveOligomerTableViewSortProxyModel.hpp"
-#include "Oligomer.hpp"
-#include "CleavageDlg.hpp"
-#include "CleaveOligomerTableViewMimeData.hpp"
+#include<QMessageBox> /////////////////////// Local includes #include <massxpert/nongui/globals.hpp>
+#include <massxpert/gui/CleaveOligomerTableView.hpp>
+#include <massxpert/gui/CleaveOligomerTableViewSortProxyModel.hpp>
+#include <massxpert/nongui/Oligomer.hpp>
+#include <massxpert/gui/CleavageDlg.hpp>
+#include <massxpert/gui/CleaveOligomerTableViewMimeData.hpp>
 
 
 namespace msXpSmassXpert
