@@ -38,8 +38,8 @@
 #include<QFileDialog>
 
 /////////////////////// Local includes
-#include "CompositionsDlg.hpp"
-#include "Coordinates.hpp"
+#include <massxpert/gui/CompositionsDlg.hpp>
+#include <massxpert/nongui/Coordinates.hpp>
 
 namespace msXpSmassXpert
 {
