@@ -38,9 +38,9 @@
 
 
 /////////////////////// Local includes
-#include "CrossLinkerDefDlg.hpp"
-#include "PolChemDef.hpp"
-#include "PolChemDefWnd.hpp"
+#include <massxpert/gui/CrossLinkerDefDlg.hpp>
+#include <massxpert/nongui/PolChemDef.hpp>
+#include <massxpert/gui/PolChemDefWnd.hpp>
 
 
 namespace msXpSmassXpert
