@@ -39,7 +39,7 @@
 
 
 /////////////////////// Local includes
-#include "FragmentationDlg.hpp"
+#include <massxpert/gui/FragmentationDlg.hpp>
 
 
 namespace msXpSmassXpert
