@@ -28,12 +28,13 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  * 
  * END software license
-*/
+ */
 
 
 
 
 /////////////////////// Qt includes
+#include <QSysInfo>
 #include <QString>
 #include <QtGui>
 #include <QtXml>
@@ -272,6 +273,10 @@ namespace msXpSmassXpert
 			 * #define MSXPERTSUITE_BIN_DIR C:/Program Files/msxpertsuite
 			 * #define MSXPERTSUITE_DATA_DIR C:/Program Files/msxpertsuite/data
 			 * #define MSXPERTSUITE_DOC_DIR C:/Program Files/msxpertsuite/doc/
+			 *
+			 * This means that for the massxpert module, the data will be copied as 
+			 * C:/Program Files/msxpertsuite/data/massxpert, with the data immediately
+			 * in that directory, not in a 'data' subdirectory.
 			 */
 
 			// On GNU/Linux, instead, the following variables are defined:
@@ -280,21 +285,53 @@ namespace msXpSmassXpert
 			 * #define MSXPERTSUITE_BIN_DIR /usr/local/bin
 			 * #define MSXPERTSUITE_DATA_DIR /usr/local/share/msxpertsuite
 			 * #define MSXPERTSUITE_DOC_DIR: /usr/local/share/doc/msxpertsuite/
+			 *
+			 * This means that for the massxpert module, the data will be copied as 
+			 * /usr/local/share/msxpertsuite/massxpert with the data immediately in
+			 * that directory, not in a 'data' subdirectory.
 			 */
 
-			// Now, it might be of interest for the user to install the software data
-			// in another location than the canonical one. In this case, the program
-			// should still be able to access the data.
+			/* On Mac OS X, instead, the software is built and then copied into a Mac
+			 * Bundle massXpert.app, which installs anywhere as long as its internal
+			 * structure is conserved. There is an API to identify from which location
+			 * the bundle is used (double-clicking onto the massXpert.app icon). We
+			 * use that API to get the bundle directory, which might be something like
+			 * /Applications/massXpert.app if the bundle was dropped into
+			 * /Applications.
+			 */
 
-			// We will try to establish if the data that were built along the software
-			// package are actually located in the cnaonical places listed above. If
-			// not, this function returns false. The caller might then take actions to
-			// let the user manually instruct the program of where the data are
-			// located.
+#if defined (Q_WS_MAC)
 
-			// All this procedure is setup so as to let the user install the software
-			// wherever she wants.
+#if 0
 
+			CFURLRef bundleRef = CFBundleCopyBundleURL(CFBundleGetMainBundle());
+
+			CFStringRef macPath = 
+				CFURLCopyFileSystemPath(bundleRef, kCFURLPOSIXPathStyle);
+
+			QString bundleDir = 
+				CFStringGetCStringPtr(macPath, CFStringGetSystemEncoding());
+
+			CFRelease(bundleRef);
+			CFRelease(macPath);
+#endif
+
+
+#endif
+
+			// Now, it might be of interest for the user to install the
+			// software in another location than the canonical one. In this
+			// case, the program should still be able to access the data.
+
+			// This is what this function is for. This function will try to
+			// establish if the data that were built along the software
+			// package are actually located in the cnaonical places listed
+			// above. If not, this function returns false. The caller might
+			// then take actions to let the user manually instruct the program
+			// of where the data are located.
+
+			// All this procedure is setup so as to let the user install the
+			// software wherever she wants.
 
 			// Settings are set according to a well-defined manner:
 			//
@@ -314,9 +351,9 @@ namespace msXpSmassXpert
 			int errorCount = 0;
 
 
-			/////////////////// MSXPERTSUITE_DATA_DIR<modulename> ///////////////////
-			/////////////////// MSXPERTSUITE_DATA_DIR<modulename> ///////////////////
-			/////////////////// MSXPERTSUITE_DATA_DIR<modulename> ///////////////////
+			/////////////////// MSXPERTSUITE_DATA_DIR ///////////////////
+			/////////////////// MSXPERTSUITE_DATA_DIR ///////////////////
+			/////////////////// MSXPERTSUITE_DATA_DIR ///////////////////
 
 			QSettings settings(m_configSettingsFilePath, QSettings::IniFormat);
 			settings.beginGroup("systemDataConfigSettings");
@@ -337,9 +374,27 @@ namespace msXpSmassXpert
 			{
 				/////// From the config.h file
 
-				// That would be /usr/local/share/msxpertsuite/<modulename>
-				// that is, /usr/local/share/msxpertsuite/massxpert, for example.
-				testDir.setPath(QString("%1/%2").arg(MSXPERTSUITE_DATA_DIR).arg(m_moduleName));
+				if(QSysInfo::productType() == "osx" || QSysInfo::productType() == "macos")
+				{
+					// Well, if we are on MacOSX, then we need to know where the bundle is
+					// located. Then, we'll craft the directory by appending
+					// "Contents/Resources/data".
+
+					testDir.setPath(QString("%1/../Resources/data").arg(QCoreApplication::applicationDirPath()));
+
+					//QMessageBox::information(this, 
+					//"dir path",
+					//QCoreApplication::applicationDirPath(), QMessageBox::Ok);
+				}
+				else
+				{
+					// On UNIX, that would be /usr/local/share/msxpertsuite/<modulename>
+					// that is, /usr/local/share/msxpertsuite/massxpert, for example.
+					testDir.setPath(QString("%1").arg(MSXPERTSUITE_DATA_DIR));
+				}
+
+				qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()" 
+					<< "dir: " << QString("%1").arg(MSXPERTSUITE_DATA_DIR);
 
 				// The path must be absolute and must exist.
 
@@ -362,6 +417,14 @@ namespace msXpSmassXpert
 				}
 			}
 
+			//QMessageBox::information(this, 
+					//"data dir path",
+					//finalDir.absolutePath(), QMessageBox::Ok);
+
+			//QMessageBox::information(this, 
+					//"module",
+					//m_moduleName, QMessageBox::Ok);
+
 			// And now craft the ConfigSetting instance:
 
 			configSetting = new ConfigSetting(m_moduleName);
@@ -380,8 +443,6 @@ namespace msXpSmassXpert
 
 			testDir.setPath(settings.value("polChemDefsDir").toString());
 
-			/////// From the config.h file
-
 			if(testDir.exists())
 			{
 				// Ah ah, the user already configured a new directory. Fine, let's go
@@ -394,9 +455,8 @@ namespace msXpSmassXpert
 
 				// That would be /usr/local/share/msxpertsuite/<modulename>/polChemDefs
 				// that is, /usr/local/share/msxpertsuite/massxpert/polChemDefs, for example.
-				testDir.setPath(QString("%1/%2/%3")
+				testDir.setPath(QString("%1/%2")
 						.arg(MSXPERTSUITE_DATA_DIR)
-						.arg(m_moduleName)
 						.arg("polChemDefs"));
 
 				if (testDir.exists() && testDir.isAbsolute())
@@ -447,9 +507,8 @@ namespace msXpSmassXpert
 
 				// That would be /usr/local/share/msxpertsuite/<modulename>/polSeqs
 				// that is, /usr/local/share/msxpertsuite/massxpert/polSeqs, for example.
-				testDir.setPath(QString("%1/%2/%3")
+				testDir.setPath(QString("%1/%2")
 						.arg(MSXPERTSUITE_DATA_DIR)
-						.arg(m_moduleName)
 						.arg("polSeqs"));
 
 				// The path must be absolute and must exist.
@@ -860,23 +919,23 @@ namespace msXpSmassXpert
 
 			msXpS::ATOM_DEC_PLACES =
 				settings.value("ATOM_DEC_PLACES", 10).toInt();
-			//     qDebug() << __FILE__ << __LINE__
-			// 	   << "ATOM_DEC_PLACES" << ATOM_DEC_PLACES;
+			// qDebug() << __FILE__ << __LINE__
+			// << "ATOM_DEC_PLACES" << ATOM_DEC_PLACES;
 
 			msXpS::OLIGOMER_DEC_PLACES =
 				settings.value("OLIGOMER_DEC_PLACES", 5).toInt();
-			//     qDebug() << __FILE__ << __LINE__
-			// 	   << "OLIGOMER_DEC_PLACES" << OLIGOMER_DEC_PLACES;
+			// qDebug() << __FILE__ << __LINE__
+			// << "OLIGOMER_DEC_PLACES" << OLIGOMER_DEC_PLACES;
 
 			msXpS::POLYMER_DEC_PLACES =
 				settings.value("POLYMER_DEC_PLACES", 3).toInt();
-			//     qDebug() << __FILE__ << __LINE__
-			// 	   << "POLYMER_DEC_PLACES" << POLYMER_DEC_PLACES;
+			// qDebug() << __FILE__ << __LINE__
+			// << "POLYMER_DEC_PLACES" << POLYMER_DEC_PLACES;
 
 			msXpS::PH_PKA_DEC_PLACES =
 				settings.value("PH_PKA_DEC_PLACES", 2).toInt();
-			//     qDebug() << __FILE__ << __LINE__
-			// 	   << "PH_PKA_DEC_PLACES" << PH_PKA_DEC_PLACES;
+			// qDebug() << __FILE__ << __LINE__
+			// << "PH_PKA_DEC_PLACES" << PH_PKA_DEC_PLACES;
 
 			settings.endGroup();
 		}
@@ -886,7 +945,7 @@ namespace msXpSmassXpert
 		MainWindow::setLastFocusedSeqEdWnd(SequenceEditorWnd *wnd)
 		{
 			mp_lastFocusedSeqEdWnd = wnd;
-			//   qDebug() << __FILE__<< __LINE__ << wnd;
+			// qDebug() << __FILE__<< __LINE__ << wnd;
 		}
 
 
@@ -948,8 +1007,8 @@ namespace msXpSmassXpert
 			{
 				polChemDef = m_polChemDefList.at(iter);
 
-				// 	qDebug() << __FILE__ << __LINE__
-				// 		 << "iterated polChemDef:" << polChemDef->name();
+				// qDebug() << __FILE__ << __LINE__
+				// << "iterated polChemDef:" << polChemDef->name();
 
 				if(polChemDef->name() == name)
 					return polChemDef;
