@@ -40,7 +40,7 @@
 
 
 /////////////////////// Local includes
-#include "MassSearchDlg.hpp"
+#include <massxpert/gui/MassSearchDlg.hpp>
 
 
 namespace msXpSmassXpert
