@@ -38,7 +38,7 @@
 
 
 /////////////////////// Local includes
-#include "MonomerCrossLinkDlg.hpp"
+#include <massxpert/gui/MonomerCrossLinkDlg.hpp>
 
 
 namespace msXpSmassXpert
