@@ -39,7 +39,7 @@
 
 
 /////////////////////// Local includes
-#include "MonomerModificationDlg.hpp"
+#include <massxpert/gui/MonomerModificationDlg.hpp>
 
 
 namespace msXpSmassXpert
