@@ -41,9 +41,9 @@
 
 
 /////////////////////// Local includes
-#include "MzCalculationDlg.hpp"
-#include "PolChemDef.hpp"
-#include "SpectrumCalculationDlg.hpp"
+#include <massxpert/gui/MzCalculationDlg.hpp>
+#include <massxpert/nongui/PolChemDef.hpp>
+#include <massxpert/gui/SpectrumCalculationDlg.hpp>
 
 
 namespace msXpSmassXpert
