@@ -41,18 +41,18 @@
 #include <QMessageBox>
 
 /////////////////////// Local includes
-#include "MzLabInputOligomerTableView.hpp"
-#include "MzLabInputOligomerTableViewModel.hpp"
+#include <massxpert/gui/MzLabInputOligomerTableView.hpp>
+#include <massxpert/gui/MzLabInputOligomerTableViewModel.hpp>
 
-#include "Oligomer.hpp"
+#include <massxpert/nongui/Oligomer.hpp>
 
-#include "MzLabInputOligomerTableViewDlg.hpp"
+#include <massxpert/gui/MzLabInputOligomerTableViewDlg.hpp>
 
-#include "CleaveOligomerTableViewMimeData.hpp"
-#include "FragmentOligomerTableViewMimeData.hpp"
-#include "MassSearchOligomerTableViewMimeData.hpp"
+#include <massxpert/gui/CleaveOligomerTableViewMimeData.hpp>
+#include <massxpert/gui/FragmentOligomerTableViewMimeData.hpp>
+#include <massxpert/gui/MassSearchOligomerTableViewMimeData.hpp>
 
-#include "Coordinates.hpp"
+#include <massxpert/nongui/Coordinates.hpp>
 
 namespace msXpSmassXpert
 {
