@@ -44,10 +44,10 @@
 
 
 /////////////////////// Local includes
-#include "MzLabInputOligomerTableViewDlg.hpp"
-#include "MzLabWnd.hpp"
-#include "MzLabInputOligomerTableViewModel.hpp"
-#include "MainWindow.hpp"
+#include <massxpert/gui/MzLabInputOligomerTableViewDlg.hpp>
+#include <massxpert/gui/MzLabWnd.hpp>
+#include <massxpert/gui/MzLabInputOligomerTableViewModel.hpp>
+#include <massxpert/gui/MainWindow.hpp>
 
 
 namespace msXpSmassXpert
