@@ -40,8 +40,8 @@
 
 
 /////////////////////// Local includes
-#include "PolChemDefWnd.hpp"
-#include "MainWindow.hpp"
+#include <massxpert/gui/PolChemDefWnd.hpp>
+#include <massxpert/gui/MainWindow.hpp>
 
 
 namespace msXpSmassXpert
