@@ -40,12 +40,12 @@
 
 
 /////////////////////// Local includes
-#include "SequenceEditorGraphicsView.hpp"
-#include "MonomerCodeEvaluator.hpp"
-#include "ChemEntVignette.hpp"
-#include "ChemEntVignetteRenderer.hpp"
-#include "PolChemDef.hpp"
-#include "Coordinates.hpp"
+#include <massxpert/gui/SequenceEditorGraphicsView.hpp>
+#include <massxpert/gui/MonomerCodeEvaluator.hpp>
+#include <massxpert/nongui/ChemEntVignette.hpp>
+#include <massxpert/nongui/ChemEntVignetteRenderer.hpp>
+#include <massxpert/nongui/PolChemDef.hpp>
+#include <massxpert/nongui/Coordinates.hpp>
 #include <cmath>
 
 
