@@ -35,7 +35,7 @@
 
 
 /////////////////////// Local includes
-#include "SequenceEditorGraphicsViewKeySequenceHandling.hpp"
+#include <massxpert/gui/SequenceEditorGraphicsViewKeySequenceHandling.hpp>
 
 
 namespace msXpSmassXpert
