@@ -41,30 +41,30 @@
 #include<QFileDialog>
 
 /////////////////////// Local includes
-#include "globals.hpp"
-#include "SequenceEditorWnd.hpp"
-#include "MainWindow.hpp"
-#include "SequenceEditorGraphicsView.hpp"
-#include "SequenceEditorFindDlg.hpp"
-#include "MonomerModificationDlg.hpp"
-#include "PolymerModificationDlg.hpp"
-#include "MonomerCrossLinkDlg.hpp"
-#include "CleavageDlg.hpp"
-#include "FragmentationDlg.hpp"
-#include "MassSearchDlg.hpp"
-#include "SequencePurificationDlg.hpp"
-#include "SequenceImportDlg.hpp"
-#include "CalculatorWnd.hpp"
-#include "MzCalculationDlg.hpp"
-#include "CompositionsDlg.hpp"
-#include "PkaPhPi.hpp"
-#include "PkaPhPiDataParser.hpp"
-#include "PkaPhPiDlg.hpp"
-#include "CrossLink.hpp"
-#include "CrossLinkerSpec.hpp"
-#include "DecimalPlacesOptionsDlg.hpp"
-#include "MonomerDictionary.hpp"
-#include "ConfigSetting.hpp"
+#include <massxpert/nongui/globals.hpp>
+#include <massxpert/gui/SequenceEditorWnd.hpp>
+#include <massxpert/gui/MainWindow.hpp>
+#include <massxpert/gui/SequenceEditorGraphicsView.hpp>
+#include <massxpert/gui/SequenceEditorFindDlg.hpp>
+#include <massxpert/gui/MonomerModificationDlg.hpp>
+#include <massxpert/gui/PolymerModificationDlg.hpp>
+#include <massxpert/gui/MonomerCrossLinkDlg.hpp>
+#include <massxpert/gui/CleavageDlg.hpp>
+#include <massxpert/gui/FragmentationDlg.hpp>
+#include <massxpert/gui/MassSearchDlg.hpp>
+#include <massxpert/gui/SequencePurificationDlg.hpp>
+#include <massxpert/gui/SequenceImportDlg.hpp>
+#include <massxpert/gui/CalculatorWnd.hpp>
+#include <massxpert/gui/MzCalculationDlg.hpp>
+#include <massxpert/gui/CompositionsDlg.hpp>
+#include <massxpert/nongui/PkaPhPi.hpp>
+#include <massxpert/nongui/PkaPhPiDataParser.hpp>
+#include <massxpert/gui/PkaPhPiDlg.hpp>
+#include <massxpert/nongui/CrossLink.hpp>
+#include <massxpert/nongui/CrossLinkerSpec.hpp>
+#include <massxpert/gui/DecimalPlacesOptionsDlg.hpp>
+#include <massxpert/nongui/MonomerDictionary.hpp>
+#include <massxpert/nongui/ConfigSetting.hpp>
 
 
 namespace msXpSmassXpert
