@@ -48,9 +48,9 @@ using namespace std;
 
 
 /////////////////////// Local includes
-#include "SpectrumCalculationDlg.hpp"
-#include "libmass/IsotopicPatternCalculator.hpp"
-#include "CalculatorWnd.hpp"
+#include <massxpert/gui/SpectrumCalculationDlg.hpp>
+#include <libmass/IsotopicPatternCalculator.hpp>
+#include <massxpert/gui/CalculatorWnd.hpp>
 
 
 namespace msXpSmassXpert
@@ -2272,11 +2272,11 @@ namespace msXpSmassXpert
  *                                                                         *
  ***************************************************************************/
 
-#include "global.h"
-#include "ipc.h"
-#include "pars.h"
-#include "element.h"
-#include "gp_out.h"
+#include <global.h>
+#include <ipc.h>
+#include <pars.h>
+#include <element.h>
+#include <gp_out.h>
 #include <time.h>
 #include <signal.h>
 #include <math.h>
