@@ -33,7 +33,7 @@
 
 
 /////////////////////// Local includes
-#include "Cleaver.hpp"
+#include <massxpert/nongui/Cleaver.hpp>
 
 
 namespace msXpSmassXpert
