@@ -28,12 +28,12 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  * 
  * END software license
-*/
+ */
 
 
 
-#ifndef CONFIG_SETTINGS_HPP
-#define CONFIG_SETTINGS_HPP
+#pragma once
+
 
 /////////////////////// Qt includes
 #include <QString>
@@ -47,40 +47,39 @@
 namespace msXpSmassXpert
 {
 
-  class ConfigSetting;
+	class ConfigSetting;
 
 
-  class ConfigSettings
+	class ConfigSettings
 
-  {
-    // The key of the map is the key of the corresponding ConfigSetting.
-    private:
-    QList<ConfigSetting *> m_configSettingList;
+	{
+		// The key of the map is the key of the corresponding ConfigSetting.
+		private:
+			QList<ConfigSetting *> m_configSettingList;
 
-    // The module name can be massxpert, mobxpert or viewxpert, for
-    // example.
-    QString m_moduleName;
+			// The module name can be massxpert, mobxpert or viewxpert, for
+			// example.
+			QString m_moduleName;
 
-    public:
-    ConfigSettings(const QString &moduleName);
-    ConfigSettings(const ConfigSettings &other);
-    ConfigSettings &operator=(const ConfigSettings &other);
+		public:
+			ConfigSettings(const QString &moduleName);
+			ConfigSettings(const ConfigSettings &other);
+			ConfigSettings &operator=(const ConfigSettings &other);
 
-    ~ConfigSettings();
+			~ConfigSettings();
 
-    void setModuleName(const QString &moduleName);
-    QString moduleName();
+			void setModuleName(const QString &moduleName);
+			QString moduleName();
 
-    void append(ConfigSetting *configSetting);
+			void append(ConfigSetting *configSetting);
 
-    QString              key(ConfigSetting *) const;
-    const ConfigSetting *value(QString key, int userType) const;
-    const QList<ConfigSetting *> *values() const;
+			QString key(ConfigSetting *) const;
+			const ConfigSetting *value(QString key, int userType) const;
+			const QList<ConfigSetting *> *values() const;
 
-    QString *text() const;
-  };
+			QString *text() const;
+	};
 
 } // namespace msXpSmassXpert
 
 
-#endif /* CONFIG_SETTINGS_HPP */
