@@ -37,7 +37,7 @@
 
 
 /////////////////////// Local includes
-#include "Fragmenter.hpp"
+#include <massxpert/nongui/Fragmenter.hpp>
 
 
 namespace msXpSmassXpert
