@@ -37,8 +37,8 @@
 
 
 /////////////////////// Local includes
-#include "Ionizable.hpp"
-#include "PolChemDef.hpp"
+#include <massxpert/nongui/Ionizable.hpp>
+#include <massxpert/nongui/PolChemDef.hpp>
 
 
 namespace msXpSmassXpert
