@@ -33,10 +33,10 @@
 
 
 /////////////////////// Local includes
-#include "globals/globals.hpp"
-#include "Modif.hpp"
-#include "PolChemDef.hpp"
-#include "Monomer.hpp"
+#include <globals/globals.hpp>
+#include <massxpert/nongui/Modif.hpp>
+#include <massxpert/nongui/PolChemDef.hpp>
+#include <massxpert/nongui/Monomer.hpp>
 
 
 namespace msXpSmassXpert
