@@ -33,9 +33,9 @@
 
 
 /////////////////////// Local includes
-#include "Monomer.hpp"
-#include "PolChemDef.hpp"
-#include "CrossLink.hpp"
+#include <massxpert/nongui/Monomer.hpp>
+#include <massxpert/nongui/PolChemDef.hpp>
+#include <massxpert/nongui/CrossLink.hpp>
 
 
 namespace msXpSmassXpert
