@@ -33,9 +33,9 @@
 
 
 /////////////////////// Local includes
-#include "Oligomer.hpp"
-#include "Polymer.hpp"
-#include "libmass/IonizeRule.hpp"
+#include <massxpert/nongui/Oligomer.hpp>
+#include <massxpert/nongui/Polymer.hpp>
+#include <libmass/IonizeRule.hpp>
 
 
 namespace msXpSmassXpert
