@@ -37,7 +37,7 @@
 
 
 /////////////////////// Local includes
-#include "PkaPhPi.hpp"
+#include <massxpert/nongui/PkaPhPi.hpp>
 
 
 namespace msXpSmassXpert
