@@ -37,11 +37,11 @@
 
 
 /////////////////////// Local includes
-#include "PolChemDef.hpp"
-#include "Monomer.hpp"
-#include "Polymer.hpp"
-#include "Modification_default_vignette.hpp"
-#include "Cross_link_default_vignette.hpp"
+#include <massxpert/nongui/PolChemDef.hpp>
+#include <massxpert/nongui/Monomer.hpp>
+#include <massxpert/nongui/Polymer.hpp>
+#include <massxpert/nongui/Modification_default_vignette.hpp>
+#include <massxpert/nongui/Cross_link_default_vignette.hpp>
 
 
 namespace msXpSmassXpert
