@@ -34,10 +34,10 @@
 
 
 /////////////////////// Local includes
-#include "Polymer.hpp"
-#include "Modif.hpp"
-#include "FragSpec.hpp"
-#include "CleaveSpec.hpp"
+#include <massxpert/nongui/Polymer.hpp>
+#include <massxpert/nongui/Modif.hpp>
+#include <massxpert/nongui/FragSpec.hpp>
+#include <massxpert/nongui/CleaveSpec.hpp>
 
 
 namespace msXpSmassXpert
