@@ -33,9 +33,9 @@
 
 
 /////////////////////// Local includes
-#include "Prop.hpp"
-#include "ChemicalGroup.hpp"
-#include "CrossLink.hpp"
+#include <massxpert/nongui/Prop.hpp>
+#include <massxpert/nongui/ChemicalGroup.hpp>
+#include <massxpert/nongui/CrossLink.hpp>
 
 
 namespace msXpSmassXpert
