@@ -33,8 +33,8 @@
 
 
 /////////////////////// Local includes
-#include "Sequence.hpp"
-#include "PolChemDef.hpp"
+#include <massxpert/nongui/Sequence.hpp>
+#include <massxpert/nongui/PolChemDef.hpp>
 
 
 namespace msXpSmassXpert
