@@ -34,7 +34,7 @@
 ////////////////////////////// Qt includes
 
 ////////////////////////////// Local includes
-#include "globals.hpp"
+#include <massxpert/nongui/globals.hpp>
 
 
 namespace msXpSmassXpert
