@@ -35,9 +35,9 @@
 ///////////////////////////// Qt includes
 
 ///////////////////////////// Local includes
-#include "AbstractMultiPlotWnd.hpp"
-#include "MainWindow.hpp"
-#include "globals.hpp"
+#include <minexpert/gui/AbstractMultiPlotWnd.hpp>
+#include <minexpert/gui/MainWindow.hpp>
+#include <minexpert/nongui/globals.hpp>
 
 
 namespace msXpSmineXpert
@@ -164,7 +164,6 @@ namespace msXpSmineXpert
 			mp_centralWidgetGridLayout->setObjectName(
 					QStringLiteral("mp_centralWidgetGridLayout"));
 
-
 			// Now that the main layout is set to the central widget, let's pack the
 			// scroll area in it. Upon adding the area to the layout, that area is
 			// reparented to the layout that is responsible for its destruction.
@@ -237,7 +236,7 @@ namespace msXpSmineXpert
 			mp_statusBarCancelPushButton->setVisible(false);
 
 			// Tool bar
-			QToolBar *mp_toolbar = addToolBar("Settings");
+			mp_toolbar = addToolBar("Settings");
 			mp_toolbar->setObjectName(QStringLiteral("mp_toolbar"));
 
 			const QIcon xRangeIcon = QIcon(":/images/lock-x-range.png");
@@ -257,13 +256,25 @@ namespace msXpSmineXpert
 			mp_lockYRangeAct->setCheckable(true);
 			mp_lockYRangeAct->setShortcuts(QList<QKeySequence>{
 					QKeySequence(Qt::CTRL + Qt::Key_L, Qt::CTRL + Qt::Key_Y)});
-			mp_lockXRangeAct->setStatusTip(tr("Lock Y range"));
+			mp_lockYRangeAct->setStatusTip(tr("Lock Y range"));
 
 			connect(mp_lockYRangeAct, &QAction::toggled, this,
 					&AbstractMultiPlotWnd::lockYRangeToggle);
 
 			mp_toolbar->addAction(mp_lockYRangeAct);
 
+			const QIcon plotWidgetHelpIcon = QIcon(":/images/plot-widget-help.png");
+			QAction *mp_plotHelperAct = new QAction(plotWidgetHelpIcon, tr("Show a help summary"), this);
+			mp_plotHelperAct->setCheckable(false);
+			mp_plotHelperAct->setShortcuts(QList<QKeySequence>{
+					QKeySequence(Qt::CTRL + Qt::Key_S, Qt::CTRL + Qt::Key_H)});
+			mp_plotHelperAct->setStatusTip(tr("Show a help summary"));
+
+			connect(mp_plotHelperAct, &QAction::triggered,
+					[&](){emit showHelpSummarySignal();});
+
+			mp_toolbar->addAction(mp_plotHelperAct);
+
 			// Finally, make sure that the window has a meaningful title:
 			setWindowTitle(QString("%1 - %2").arg(m_name).arg(m_desc));
 
@@ -298,7 +309,7 @@ namespace msXpSmineXpert
 	QCPGraph *
 		AbstractMultiPlotWnd::multiGraph(AbstractPlotWidget *plotWidget)
 		{
-			if(plotWidget == nullptr)
+			if(plotWidget == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.",
 						__FILE__, __LINE__);
 
@@ -321,7 +332,7 @@ namespace msXpSmineXpert
 	AbstractPlotWidget *
 		AbstractMultiPlotWnd::monoGraphPlot(QCPGraph *graph)
 		{
-			if(graph == nullptr)
+			if(graph == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.",
 						__FILE__, __LINE__);
 
@@ -351,17 +362,18 @@ namespace msXpSmineXpert
 		AbstractMultiPlotWnd::setupFeedback(QString msg, int startValue,
 				int endValue, int currentValue, int logType)
 		{
-			//qInfo() << __FILE__ << __LINE__
-				//<< "Entering" << __FUNCTION__
-				//<< "with message: " << msg 
-				//<< "and startValue:" << startValue 
-				//<< "and endValue:" << endValue 
-				//<< "and currentValue:" << currentValue
-				//<< "and log type:" << logType;
+			//qDebug() << __FILE__ << __LINE__
+			//<< "Entering" << __FUNCTION__
+			//<< "with message: " << msg 
+			//<< "and startValue:" << startValue 
+			//<< "and endValue:" << endValue 
+			//<< "and currentValue:" << currentValue
+			//<< "and log type:" << logType;
 
 			if(logType & LogType::LOG_TO_CONSOLE)
 			{
-				qInfo() << "log type to console";
+				//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()" 
+				//<< "log type to console";
 				MainWindow *mainWindow = static_cast<MainWindow *>(parent());
 				mainWindow->logConsoleMessage(msg);
 			}
@@ -415,11 +427,11 @@ namespace msXpSmineXpert
 	void
 		AbstractMultiPlotWnd::updateFeedback(QString msg, int currentValue, int logType)
 		{
-			//qInfo() << __FILE__ << __LINE__
-				//<< "Entering" << __FUNCTION__
-				//<< "with message: " << msg 
-				//<< "and currentValue:" << currentValue
-				//<< "and log type:" << logType;
+			//qDebug() << __FILE__ << __LINE__
+			//<< "Entering" << __FUNCTION__
+			//<< "with message: " << msg 
+			//<< "and currentValue:" << currentValue
+			//<< "and log type:" << logType;
 
 			if(logType & LogType::LOG_TO_CONSOLE)
 			{
@@ -483,7 +495,7 @@ namespace msXpSmineXpert
 	int
 		AbstractMultiPlotWnd::plotWidgetIndex(AbstractPlotWidget *plotWidget)
 		{
-			if(plotWidget == nullptr)
+			if(plotWidget == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
 			for(int iter = 0; iter < m_plotWidgetList.size(); ++iter)
@@ -568,19 +580,19 @@ namespace msXpSmineXpert
 	void
 		AbstractMultiPlotWnd::toggleMultiGraph(AbstractPlotWidget *widget)
 		{
-			if(widget == nullptr)
+			if(widget == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
 			QCPGraph *graph = m_plotWidgetGraphMap.value(widget);
 
-			if(graph != nullptr)
+			if(graph != Q_NULLPTR)
 			{
 				graph->setVisible(!graph->visible());
 				graph->parentPlot()->replot();
 			}
 			else
 			{
-				qDebug() << __FILE__ << __LINE__ << "graph is nullptr";
+				qDebug() << __FILE__ << __LINE__ << "graph is Q_NULLPTR";
 			}
 		}
 
@@ -595,12 +607,12 @@ namespace msXpSmineXpert
 	void
 		AbstractMultiPlotWnd::showMultiGraph(AbstractPlotWidget *widget)
 		{
-			if(widget == nullptr)
+			if(widget == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
 			QCPGraph *graph = m_plotWidgetGraphMap.value(widget);
 
-			if(graph != nullptr)
+			if(graph != Q_NULLPTR)
 			{
 
 				graph->setVisible(true);
@@ -609,7 +621,7 @@ namespace msXpSmineXpert
 			}
 			else
 			{
-				qDebug() << __FILE__ << __LINE__ << "graph is nullptr";
+				qDebug() << __FILE__ << __LINE__ << "graph is Q_NULLPTR";
 			}
 		}
 
@@ -624,19 +636,19 @@ namespace msXpSmineXpert
 	void
 		AbstractMultiPlotWnd::hideMultiGraph(AbstractPlotWidget *widget)
 		{
-			if(widget == nullptr)
+			if(widget == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
 			QCPGraph *graph = m_plotWidgetGraphMap.value(widget);
 
-			if(graph != nullptr)
+			if(graph != Q_NULLPTR)
 			{
 				graph->setVisible(false);
 				graph->parentPlot()->replot();
 			}
 			else
 			{
-				qDebug() << __FILE__ << __LINE__ << "graph is nullptr";
+				qDebug() << __FILE__ << __LINE__ << "graph is Q_NULLPTR";
 			}
 		}
 
@@ -645,11 +657,11 @@ namespace msXpSmineXpert
 	void
 		AbstractMultiPlotWnd::removeMultiGraph(AbstractPlotWidget *widget)
 		{
-			if(widget == nullptr)
+			if(widget == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
 			QCPGraph *graph = m_plotWidgetGraphMap.value(widget);
-			if(graph != nullptr)
+			if(graph != Q_NULLPTR)
 			{
 				if(graph->parentPlot()->hasPlottable(graph))
 				{
@@ -701,7 +713,7 @@ namespace msXpSmineXpert
 	void
 		AbstractMultiPlotWnd::setAnalysisPreferences(AnalysisPreferences *preferences)
 		{
-			if(preferences == nullptr)
+			if(preferences == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
 			mp_analysisPreferences = preferences;
@@ -712,7 +724,7 @@ namespace msXpSmineXpert
 	void
 		AbstractMultiPlotWnd::setAnalysisFile(QFile *analysisFile)
 		{
-			if(analysisFile == nullptr)
+			if(analysisFile == Q_NULLPTR)
 				qFatal(
 						"Fatal error at %s@%d. The file pointer cannot be 0. Program aborted.",
 						__FILE__, __LINE__);
