@@ -36,12 +36,15 @@
 
 
 ///////////////////////////// Local includes
-#include "AbstractPlotWidget.hpp"
-#include "AbstractMultiPlotWnd.hpp"
-#include "MassSpecSqlite3Handler.hpp"
-#include "SqlMassDataSlicer.hpp"
-#include "SqlMassDataSlicerDlg.hpp"
-#include "globals.hpp"
+#include <minexpert/gui/AbstractPlotWidget.hpp>
+#include <minexpert/gui/AbstractMultiPlotWnd.hpp>
+#include <minexpert/nongui/MassSpecSqlite3Handler.hpp>
+#include <minexpert/nongui/SqlMassDataSlicer.hpp>
+#include <minexpert/gui/SqlMassDataSlicerDlg.hpp>
+#include <minexpert/nongui/globals.hpp>
+#include <minexpert/gui/MainWindow.hpp>
+#include <minexpert/gui/SaveToGraphicsFileDlg.hpp>
+
 
 
 namespace msXpSmineXpert
@@ -163,8 +166,6 @@ namespace msXpSmineXpert
 			setInteractions(QCP::iRangeZoom | QCP::iSelectPlottables |
 					QCP::iMultiSelect);
 
-			createContextMenu();
-
 			addGraph();
 
 			m_pen.setStyle(Qt::SolidLine);
@@ -259,20 +260,33 @@ namespace msXpSmineXpert
 
 
 	//! Create the contextual menu.
-	void
+	QMenu *
 		AbstractPlotWidget::createContextMenu()
 		{
-			m_contextMenu = new QMenu(this);
+			if(mpa_contextMenu != Q_NULLPTR)
+				delete mpa_contextMenu;
 
-			QMenu *exportMenu = m_contextMenu->addMenu("Export");
+			mpa_contextMenu = new QMenu(this);
 
-			QAction *action = nullptr;
+			QAction *action = Q_NULLPTR;
 
-			action = exportMenu->addAction("&Data");
-			connect(action, &QAction::triggered, this, &AbstractPlotWidget::exportData);
+			if(mp_colorMap == Q_NULLPTR)
+			{
+				QMenu *exportMenu = mpa_contextMenu->addMenu("Export");
 
-			action = exportMenu->addAction("&Plot");
-			connect(action, &QAction::triggered, this, &AbstractPlotWidget::exportPlot);
+				action = exportMenu->addAction("&Data");
+				connect(action, &QAction::triggered, this, &AbstractPlotWidget::exportData);
+
+				action = exportMenu->addAction("&Plot as xy file");
+				connect(action, &QAction::triggered, this, &AbstractPlotWidget::exportPlot);
+
+				mpa_contextMenu->addSeparator();
+			}
+
+			action = mpa_contextMenu->addAction("&Save plot to graphics file");
+			connect(action, &QAction::triggered, this, &AbstractPlotWidget::savePlotToGraphicsFile);
+
+			return mpa_contextMenu;
 		}
 
 
@@ -444,22 +458,44 @@ namespace msXpSmineXpert
 			replot();
 		}
 
-
-	//! Append a keyboard key code in the list of registered key.
+	//! Insert a keyboard key code in the list of registered key.
 	/*! 
 
-		The \c m_regQtKeyCodeList list of keyboard keys is a register that stores
+		The \c m_regQtKeyCodeMap map of keyboard keys is a register that stores
 		key codes of keys that have a special meaning while working on the data
-		plotted in the plot widgets.
+		plotted in the plot widgets along with the helper string.
 
 */
 	void
-		AbstractPlotWidget::registerQtKey(int qtKeyCode)
+		AbstractPlotWidget::registerQtKeyCode(int qtKeyCode, const QString &helpText)
 		{
-			m_regQtKeyCodeList.append(qtKeyCode);
+			m_regQtKeyCodeMap.insert(qtKeyCode, helpText);
 		}
 
 
+	//! Craft a string explaining the various key combinations for the integrations.
+	void 
+		AbstractPlotWidget::showHelpSummary()
+		{
+			QString helpText;
+
+			QMapIterator<int, QString> iterator(m_regQtKeyCodeMap);
+
+			while(iterator.hasNext())
+			{
+				iterator.next();
+
+				helpText.append(iterator.value() + "\n");
+			}
+
+			QSize widgetSize = size();
+			QPoint windowPos = mp_parentWnd->pos();
+			QPoint toolTipPos = windowPos + QPoint(widgetSize.width() / 2, widgetSize.height() / 2);
+			QToolTip::showText(toolTipPos, helpText, this, QRect());
+		}
+
+
+
 	//! Set the \c m_pressedKeyCode to the key code in \p event.
 	void
 		AbstractPlotWidget::keyPressEvent(QKeyEvent *event)
@@ -605,7 +641,7 @@ namespace msXpSmineXpert
 
 			// If this plot widget is hosting the color map, there is a specific
 			// treatement.
-			if(mp_colorMap != nullptr)
+			if(mp_colorMap != Q_NULLPTR)
 			{
 				QCPAxis *xAxis = mp_colorMap->keyAxis();
 
@@ -684,7 +720,7 @@ namespace msXpSmineXpert
 			// slice all these data in chunks of a given size (count is deduced) or
 			// b. export the data in a number of chunks (size is deduced).
 
-			if(m_isMultiGraph)
+			if(m_isMultiGraph || mp_colorMap != Q_NULLPTR)
 				return;
 
 			// At the moment, this export only works with data that are available as
@@ -718,7 +754,6 @@ namespace msXpSmineXpert
 			histItem->newIntegrationRange(arbitraryIntegrationType(), start, end);
 			localHistory.appendHistoryItem(histItem);
 
-
 			qDebug() << __FILE__ << __LINE__
 				<< "History right before slicing: " << localHistory.asText();
 
@@ -743,6 +778,54 @@ namespace msXpSmineXpert
 		}
 
 
+	QString 
+		AbstractPlotWidget::asXyText()
+		{
+			if(m_isMultiGraph)
+				return QString();
+
+			// Get the pointer to the x-axis (key axis).
+
+			QCPAxis *xAxis = graph()->keyAxis();
+
+			double rangeStart = xAxis->range().lower;
+			double rangeEnd = xAxis->range().upper;
+
+			// Remember that the data are like this in a QCPGraph:
+			// typedef QMap< double, QCPData > QCPDataMap
+			// and the double key of the map is the key of QCPData:
+			// QCPData(key, value).
+
+			QCPDataMap *data = graph()->data();
+
+			QList<double> xValueList = data->keys();
+
+			QString xyString;
+
+			for(int iter = 0; iter < xValueList.size(); ++iter)
+			{
+				double xValue = xValueList.at(iter);
+
+				if(xValue >= rangeStart)
+				{
+					if(xValue <= rangeEnd)
+					{
+						double yValue = data->value(xValue).value;
+
+						xyString += QString("%1 %2\n")
+							.arg(xValue, 0, 'f', 10)
+							.arg(yValue, 0, 'f', 10);
+					}
+					else
+						break;
+				}
+			}
+
+			return xyString;
+		}
+
+
+
 	//! Export plot data to a text file as a simple plot.
 	/*!
 
@@ -777,52 +860,19 @@ namespace msXpSmineXpert
 
 			outputFileName = newFileName;
 
-			// Get the pointer to the x-axis (key axis).
-
-			QCPAxis *xAxis = graph()->keyAxis();
-
-			double rangeStart = xAxis->range().lower;
-			double rangeEnd = xAxis->range().upper;
-
-			// Remember that the data are like this in a QCPGraph:
-			// typedef QMap< double, QCPData > QCPDataMap
-			// and the double key of the map is the key of QCPData:
-			// QCPData(key, value).
-
-			QCPDataMap *data = graph()->data();
-
-			QList<double> xValueList = data->keys();
-
-			QString outputString;
-
-			for(int iter = 0; iter < xValueList.size(); ++iter)
-			{
-				double xValue = xValueList.at(iter);
-
-				if(xValue >= rangeStart)
-				{
-					if(xValue <= rangeEnd)
-					{
-						double yValue = data->value(xValue).value;
-
-						outputString += QString("%1 %2\n")
-							.arg(xValue, 0, 'g', 10)
-							.arg(yValue, 0, 'g', 10);
-					}
-					else
-						break;
-				}
-			}
+			QString xyString = asXyText();
 
 			QFile file(outputFileName);
 
 			file.open(QIODevice::WriteOnly);
 			QTextStream out(&file); // we will serialize the data into the file
-			out << outputString;
+			out << xyString;
 
 			file.close();
 		}
 
+
+
 	//! Export plot data to a text file as a simple plot.
 	/*!
 
@@ -839,10 +889,9 @@ namespace msXpSmineXpert
 				return;
 
 			// The user asks that the (that is not the whole set of data), but only
-			// the
-			// x,y plot for the current plot widget. This is the easiest solution. The
-			// only constraint is that we only export the data corresponding to the
-			// current X axis range.
+			// the x,y plot for the current plot widget. This is the easiest solution.
+			// The only constraint is that we only export the data corresponding to
+			// the current X axis range.
 
 			QString outputFileName = fileName;
 
@@ -902,8 +951,8 @@ namespace msXpSmineXpert
 						double yValue = data->value(xValue).value;
 
 						outputString += QString("%1 %2\n")
-							.arg(xValue, 0, 'g', 10)
-							.arg(yValue, 0, 'g', 10);
+							.arg(xValue, 0, 'f', 10)
+							.arg(yValue, 0, 'f', 10);
 					}
 					else
 						break;
@@ -912,7 +961,7 @@ namespace msXpSmineXpert
 
 			// Now craft a header that will identify clearly the data. The '#' is a
 			// comment prefix.
-			
+
 			QString header;
 
 			QFile file(outputFileName);
@@ -924,7 +973,7 @@ namespace msXpSmineXpert
 
 				return;
 			}
-		
+
 			//qWarning() << "opened file with text:" << outputString;
 
 			QTextStream out(&file); // we will serialize the data into the file
@@ -934,6 +983,113 @@ namespace msXpSmineXpert
 		}
 
 
+	bool 
+		AbstractPlotWidget::savePlotToGraphicsFile()
+		{
+			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()" 
+				<< "There.";
+
+			SaveToGraphicsFileDlg dlg(this, this, "mineXpert");
+
+			if(QDialog::Accepted == dlg.exec())
+				return true;
+			else
+				return false;
+		}
+
+
+	bool 
+		AbstractPlotWidget::saveToPdfFile(const QString &fileName, 
+				bool noCosmeticPen, int width, int height, 
+				const QString &pdfCreator, const QString &title)
+		{
+			return savePdf(fileName, noCosmeticPen, width, height, 
+					pdfCreator, title);
+		}
+
+
+	QList<double> 
+		AbstractPlotWidget::keys()
+		{
+			QList<double> keyList;
+
+			if(m_isMultiGraph)
+			{
+				qDebug() << __FILE__ << __LINE__ << __FUNCTION__
+					<< "Cannot select keys from multiGraph plot.";
+
+				return keyList;
+			}
+
+			QCPDataMap *data = graph()->data();
+
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__
+			//<< "keys:" << data->keys();
+
+			return data->keys();
+		}
+
+
+	QList<double>
+		AbstractPlotWidget::values()
+		{
+			QList<double> valueList;
+
+			if(m_isMultiGraph)
+			{
+				qDebug() << __FILE__ << __LINE__ << __FUNCTION__
+					<< "Cannot select keys from multiGraph plot.";
+
+				return valueList;
+			}
+
+			QCPDataMap *data = graph()->data();
+			QList<double> keyList = data->keys();
+
+			for(int iter = 0; iter < keyList.size(); ++iter)
+			{
+				double xValue = keyList.at(iter);
+				valueList.append(data->value(xValue).value);
+			}
+
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__
+			//<< "values:" << valueList;
+
+			return valueList;
+		}
+
+
+	msXpSlibmass::Trace
+		AbstractPlotWidget::trace()
+		{
+			if(m_isMultiGraph)
+			{
+				qDebug() << __FILE__ << __LINE__ << __FUNCTION__
+					<< "Cannot select keys from multiGraph plot.";
+
+				return msXpSlibmass::Trace();
+			}
+
+			msXpSlibmass::Trace trace;
+
+			QCPDataMap *p_data = graph()->data();
+
+			QMapIterator<double, QCPData>i(*p_data);
+
+			while (i.hasNext()) 
+			{
+				i.next();
+
+				msXpSlibmass::DataPoint *dataPoint =
+					new msXpSlibmass::DataPoint(i.value().key, i.value().value);
+
+				trace.append(dataPoint);
+			}
+
+			return trace;
+		}
+
+
 	//! Trigger a graph replot action with new x-axis and y-axis ranges.
 	void
 		AbstractPlotWidget::replotWithAxisRange(QCPRange xAxisRange,
@@ -1195,7 +1351,7 @@ namespace msXpSmineXpert
 			// We only want the arrows when we are preparing an integration
 			// operation. So check if one corresponding key is pressed.
 
-			if(m_regQtKeyCodeList.contains(m_pressedKeyCode))
+			if(m_regQtKeyCodeMap.contains(m_pressedKeyCode))
 			{
 				m_selectLine->setHead(QCPLineEnding::esSpikeArrow);
 				m_selectLine->setTail(QCPLineEnding::esSpikeArrow);
@@ -1459,9 +1615,9 @@ namespace msXpSmineXpert
 		{
 			// We need to find the min and max Y values in the min->max range of the X
 			// axis.
-			QCPDataMap *data = nullptr;
+			QCPDataMap *data = Q_NULLPTR;
 
-			if(g == nullptr)
+			if(g == Q_NULLPTR)
 				data = graph()->data();
 			else
 				data = g->data();
@@ -1534,7 +1690,7 @@ namespace msXpSmineXpert
 	double
 		AbstractPlotWidget::getYatX(double k, QCPGraph *g)
 		{
-			if(g == nullptr)
+			if(g == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d -- %s. "
 						"Pointer cannot be nullptr."
 						"Program aborted.",
@@ -1591,7 +1747,7 @@ namespace msXpSmineXpert
 			// Inform the parent window that this is the last focused widget:
 			AbstractMultiPlotWnd *parentWnd =
 				dynamic_cast<AbstractMultiPlotWnd *>(mp_parentWnd);
-			if(parentWnd == nullptr)
+			if(parentWnd == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
 			if(parentWnd->mp_lastFocusedPlotWidget != this)
@@ -1938,11 +2094,14 @@ namespace msXpSmineXpert
 					// We only support data export on non-multi-graph plot widgets and on
 					// non-color-map widgets.
 
-					if(!m_isMultiGraph && mp_colorMap == nullptr)
+					if(m_isMultiGraph)
 					{
-						m_contextMenu->popup(QCursor::pos());
+						event->accept();
+						return;
 					}
 
+					createContextMenu()->popup(QCursor::pos());
+
 					event->accept();
 					return;
 				}
@@ -1993,7 +2152,7 @@ namespace msXpSmineXpert
 
 				// Now see what we need to do depending on the key pressed code or
 				// nothing.
-				if(m_regQtKeyCodeList.contains(m_pressedKeyCode))
+				if(m_regQtKeyCodeMap.contains(m_pressedKeyCode))
 				{
 					mouseReleaseHandledEvent(event);
 				}
@@ -2231,7 +2390,7 @@ namespace msXpSmineXpert
 	void
 		AbstractPlotWidget::redrawPlotBackground(QWidget *focusedPlotWidget)
 		{
-			if(focusedPlotWidget == nullptr)
+			if(focusedPlotWidget == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
 			if(dynamic_cast<QWidget *>(this) != focusedPlotWidget)
