@@ -43,12 +43,13 @@
 
 
 /////////////////////// QCustomPlot
-//#include "qcustomplot-fr.hpp"
-#include "qcustomplot.h"
+#include <qcustomplot.h>
+
 
 ///////////////////////////// Local includes
-#include "History.hpp"
-#include "MassSpecDataSet.hpp"
+#include <minexpert/nongui/History.hpp>
+#include <libmass/Trace.hpp>
+#include <minexpert/nongui/MassSpecDataSet.hpp>
 
 
 namespace msXpSmineXpert
@@ -134,7 +135,7 @@ namespace msXpSmineXpert
 			user deletes the plot from the TIC chromatogram window.
 
 */
-		MassSpecDataSet *mp_massSpecDataSet = nullptr;
+		MassSpecDataSet *mp_massSpecDataSet = Q_NULLPTR;
 
 
 		//! The name of the data file from which the mass data were read.
@@ -168,7 +169,9 @@ namespace msXpSmineXpert
 			spectrometry data are handled.
 
 */
-		QCPColorMap *mp_colorMap = nullptr;
+		QCPColorMap *mp_colorMap = Q_NULLPTR;
+
+		bool m_areDtKeys = true;
 
 		//! History member in which to store all the events...
 		/*!
@@ -193,13 +196,13 @@ namespace msXpSmineXpert
 		History m_history;
 
 		//! Pointer to the contextual menu.
-		QMenu *m_contextMenu = nullptr;
+		QMenu *mpa_contextMenu = Q_NULLPTR;
 
 		//! Rectangle defining the borders of zoomed-in/out data.
-		QCPItemRect *m_zoomRect = nullptr;
+		QCPItemRect *m_zoomRect = Q_NULLPTR;
 
 		//! Line that is printed when the user selects a range.
-		QCPItemLine *m_selectLine = nullptr;
+		QCPItemLine *m_selectLine = Q_NULLPTR;
 
 		//! Text that is displayed on the plotted graph to document it.
 		/*! 
@@ -207,10 +210,10 @@ namespace msXpSmineXpert
 			That text is typically the file path of the data file.
 
 */
-		QCPItemText *m_descText = nullptr;
+		QCPItemText *m_descText = Q_NULLPTR;
 
 		//! Text describing the x-axis delta value during a drag operation.
-		QCPItemText *m_xDeltaText = nullptr;
+		QCPItemText *m_xDeltaText = Q_NULLPTR;
 
 		//! Tells if the tracers should be visible.
 		bool m_tracersVisible = true;
@@ -270,8 +273,9 @@ namespace msXpSmineXpert
 */
 		int m_mouseMoveHandlerSkipCount = 0;
 
-		//! List of keyboard codes registered for having a special function.
-		QList<int> m_regQtKeyCodeList;
+		//! Map of keyboard codes, registered for having a special function, with
+		//textual helper string.
+		QMap<int, QString> m_regQtKeyCodeMap;
 
 		//! Key code of the last pressed keyboard key.
 		int m_pressedKeyCode;
@@ -317,7 +321,6 @@ namespace msXpSmineXpert
 		//! Color used for the background of focused plot.
 		QBrush m_focusedBrush = QBrush(m_focusedColor);
 
-
 		public:
 
 		explicit AbstractPlotWidget(QWidget *parent, QWidget *parentWnd, const QString &name,
@@ -347,7 +350,9 @@ namespace msXpSmineXpert
 		History &rhistory(){return m_history;}
 
 		virtual bool setupWidget();
-		virtual void createContextMenu();
+		virtual QMenu *createContextMenu();
+
+		void showHelpSummary();
 
 		void clearHistory();
 		void addHistoryItem(HistoryItem *item);
@@ -372,10 +377,10 @@ namespace msXpSmineXpert
 		bool isClickOntoYAxis(const QPointF &mousePoint);
 		void calculateSortedDragDeltas();
 		void yMinMaxOnXAxisCurrentRange(double &min, double &max,
-				QCPGraph *g = nullptr);
+				QCPGraph *g = Q_NULLPTR);
 		void axisRescale();
 
-		virtual void registerQtKey(int qtKeyCode);
+		virtual void registerQtKeyCode(int qtKeyCode, const QString &helpText);
 		virtual void clearPlot();
 
 		virtual void mouseMoveHandler(QMouseEvent *event);
@@ -409,20 +414,33 @@ namespace msXpSmineXpert
 		QColor color() const;
 		void changeColor(const QColor& newColor);
 
+		Q_INVOKABLE QString asXyText();
+
 		Q_INVOKABLE virtual void exportData();
 		Q_INVOKABLE virtual void exportPlot();
 		Q_INVOKABLE virtual void exportPlotToFile(const QString &fileName, 
 				double start = qSNaN(), double end = qSNaN());
 
+		virtual bool savePlotToGraphicsFile();
+
+		Q_INVOKABLE virtual bool saveToPdfFile(const QString &fileName, 
+				bool noCosmeticPen, int width, int height, 
+				const QString &pdfCreator, const QString &title);
+
 		virtual int arbitraryIntegrationType() = 0;
 
+		Q_INVOKABLE QList<double> keys();
+		Q_INVOKABLE QList<double> values();
+
+		Q_INVOKABLE msXpSlibmass::Trace trace();
+
 signals:
 		void updateStatusBarSignal(QString msg);
 
 		void destroyMatchingMultiGraphGraph(AbstractPlotWidget *widget);
 
-		void aboutToDestroyPlotWidget(AbstractPlotWidget *widget = nullptr);
-		void destroyPlotWidget(AbstractPlotWidget *widget = nullptr);
+		void aboutToDestroyPlotWidget(AbstractPlotWidget *widget = Q_NULLPTR);
+		void destroyPlotWidget(AbstractPlotWidget *widget = Q_NULLPTR);
 
 		void toggleMultiGraphSignal(AbstractPlotWidget *widget,
 				bool recursive);
