@@ -42,10 +42,10 @@
 
 
 ///////////////////////////// Local includes
-#include "AbstractPlotWidget.hpp"
-#include "AbstractMultiPlotWnd.hpp"
-#include "MassSpecDataSet.hpp"
-#include "History.hpp"
+#include <minexpert/gui/AbstractPlotWidget.hpp>
+#include <minexpert/gui/AbstractMultiPlotWnd.hpp>
+#include <minexpert/nongui/MassSpecDataSet.hpp>
+#include <minexpert/nongui/History.hpp>
 
 
 namespace msXpSmineXpert
@@ -116,6 +116,8 @@ namespace msXpSmineXpert
 		Q_INVOKABLE double integrateToTicIntensity(double xAxisLower, double xAxisUpper,
 				double yAxisLower, double yAxisUpper);
 
+		Q_INVOKABLE void transposeAxes();
+
 
 signals:
 		void recordAnalysisStanza(QString stanza, const QColor &color = QColor());
