@@ -43,10 +43,10 @@
 
 
 /////////////////////// Local includes
-#include "AbstractMultiPlotWnd.hpp"
-#include "ColorMapPlotWidget.hpp"
-#include "AnalysisPreferences.hpp"
-#include "MassSpecDataSet.hpp"
+#include <minexpert/gui/AbstractMultiPlotWnd.hpp>
+#include <minexpert/gui/ColorMapPlotWidget.hpp>
+#include <minexpert/nongui/AnalysisPreferences.hpp>
+#include <minexpert/nongui/MassSpecDataSet.hpp>
 
 
 namespace msXpSmineXpert
@@ -84,6 +84,10 @@ namespace msXpSmineXpert
 					const QVector<double> &valVector, const QString &desc,
 					MassSpecDataSet *massSpecDataSet, bool isMultiGraph = false);
 
+			void setupWindow();
+
+			QAction *mp_transposeAxesAct = Q_NULLPTR;
+
 			//! Number of plot widgets.
 			/*!
 
