@@ -36,7 +36,7 @@
 
 
 /////////////////////// Local includes
-#include "DataPlotWidgetRelation.hpp"
+#include <minexpert/gui/DataPlotWidgetRelation.hpp>
 
 
 namespace msXpSmineXpert
@@ -185,17 +185,19 @@ namespace msXpSmineXpert
 			p_relation->mp_targetPlotWidget = target;
 			p_relation->mp_openSpectraListWidgetItem = widgetItem;
 
-			QString msg =
-				QString("New relation: 0x%1\n"
-						"\tdataSet: 0x%2\n"
-						"\torigin plot widget: 0x%3\n"
-						"\ttarget plot widget: 0x%4.\n")
-				.arg((quintptr)p_relation, QT_POINTER_SIZE * 2, 16, QChar('0'))
-				.arg((quintptr)p_relation->mp_dataSet, QT_POINTER_SIZE * 2, 16, QChar('0'))
-				.arg((quintptr)p_relation->mp_originPlotWidget, QT_POINTER_SIZE * 2, 16, QChar('0'))
-				.arg((quintptr)p_relation->mp_targetPlotWidget, QT_POINTER_SIZE * 2, 16, QChar('0'));
-
-			printf("%s", msg.toLatin1().data());
+			//QString msg =
+			//QString("New relation: 0x%1\n"
+			//"\tdataSet: 0x%2\n"
+			//"\torigin plot widget: 0x%3\n"
+			//"\ttarget plot widget: 0x%4\n"
+			//"\ttarget name: %5\n")
+			//.arg((quintptr)p_relation, QT_POINTER_SIZE * 2, 16, QChar('0'))
+			//.arg((quintptr)p_relation->mp_dataSet, QT_POINTER_SIZE * 2, 16, QChar('0'))
+			//.arg((quintptr)p_relation->mp_originPlotWidget, QT_POINTER_SIZE * 2, 16, QChar('0'))
+			//.arg((quintptr)p_relation->mp_targetPlotWidget, QT_POINTER_SIZE * 2, 16, QChar('0'))
+			//.arg(target->desc());
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
+			//fprintf(stderr, "%s", msg.toLatin1().data());
 
 			m_relationList.append(p_relation);
 		}
@@ -596,8 +598,14 @@ namespace msXpSmineXpert
 
 	bool
 		DataPlotWidgetRelationer::isLeafPlotWidget(AbstractPlotWidget * widget,
-				DataPlotWidgetRelation *relation)
+				DataPlotWidgetRelation ** pp_relation)
 		{
+			if(pp_relation == Q_NULLPTR)
+				qFatal("Fatal error at %s@%d -- %s(). "
+						"Pointer cannot be NULL."
+						"Program aborted.",
+						__FILE__, __LINE__, __FUNCTION__);
+
 			// If the widget is the last of a branch, that is, it has no target
 			// widget, in the sense that precisely it is only a target plot widget,
 			// then we should return true.
@@ -620,8 +628,7 @@ namespace msXpSmineXpert
 
 			if(relationList.size() == 1)
 			{
-				if(relation != Q_NULLPTR)
-					relation = relationList.first();
+				*pp_relation = relationList.first();
 
 				return true;
 			}
@@ -651,7 +658,7 @@ namespace msXpSmineXpert
 
 	AbstractPlotWidget *
 		DataPlotWidgetRelationer::rootPlotWidget(AbstractPlotWidget *target, 
-				DataPlotWidgetRelation **rootRelation)
+				DataPlotWidgetRelation **pp_rootRelation)
 		{
 			if(target == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d -- %s. "
@@ -659,6 +666,13 @@ namespace msXpSmineXpert
 						"Program aborted.",
 						__FILE__, __LINE__, __FUNCTION__);
 
+			if(pp_rootRelation == Q_NULLPTR)
+				qFatal("Fatal error at %s@%d -- %s(). "
+						"Pointer cannot be NULL."
+						"Program aborted.",
+						__FILE__, __LINE__, __FUNCTION__);
+
+
 			// We want to go back to the root TIC chromatogram plot widget which is
 			// the root ancestor of target. That root TIC chromatogram is the plot
 			// that is automatically created when a mass data file is loaded. Upon
@@ -666,17 +680,19 @@ namespace msXpSmineXpert
 			// widget as the target plot widget and Q_NULLPTR as the origin plot widget.
 			// This is how all the root origin plot widgets can be traced back.
 
-			QString msg =
-				QString("Entering rootPlotWidget with target 0x%1\n")
-				.arg((quintptr)target, QT_POINTER_SIZE * 2, 16, QChar('0'));
-			printf("%s", msg.toLatin1().data());
+			//QString msg =
+			//QString("Entering rootPlotWidget() with target 0x%1\n"
+			//"with name: %2 ")
+			//.arg((quintptr)target, QT_POINTER_SIZE * 2, 16, QChar('0'))
+			//.arg(target->desc());
+			//printf("%s\n", msg.toLatin1().data());
 
 			for(int iter = 0; iter < m_relationList.size(); ++iter)
 			{
 				DataPlotWidgetRelation *p_relation = m_relationList.at(iter);
 
-				printf("iter: %d relation: %s\n", iter,
-						p_relation->asText().toLatin1().data());
+				//printf("iterating in relation (index %d): %s\n", iter,
+				//p_relation->asText().toLatin1().data());
 
 				// If the target widget passed as parameter is indeed a target widget,
 				// which means it must have an origin plot widget, then, the target
@@ -685,8 +701,8 @@ namespace msXpSmineXpert
 
 				if(p_relation->mp_targetPlotWidget == target)
 				{
-					printf("\tmatching target %s\n",
-							p_relation->asText().toLatin1().data());
+					//printf("\tmatching target %s\n",
+					//p_relation->asText().toLatin1().data());
 
 					// By definition, if the mp_originPlotWidget member of the relation is
 					// Q_NULLPTR, then we have reached to top of the plot widget hierarchy
@@ -695,8 +711,9 @@ namespace msXpSmineXpert
 
 					if(p_relation->mp_originPlotWidget == Q_NULLPTR)
 					{
-						if(rootRelation != Q_NULLPTR)
-							*rootRelation = p_relation;
+						*pp_rootRelation = p_relation;
+
+						//printf("\tbecause origin plot widget is nullptr, return target that is root plog widgt\n");
 
 						return target;
 					}
@@ -705,10 +722,12 @@ namespace msXpSmineXpert
 					// Simply run this function again, by considering that
 					// p_relation->mp_originPlotWidget is actually a target plot widget:
 
-					qDebug() << __FILE__ << __LINE__ << __FUNCTION__ 
-					<< "Now going one level up.";
+					//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ 
+					//<< "Not yet found the root plot widget."
+					//<< "Recursively call with the matching origin plot "
+					//"widget used this time as the target widget: going one level up.";
 
-					return rootPlotWidget(p_relation->mp_originPlotWidget); 
+					return rootPlotWidget(p_relation->mp_originPlotWidget, pp_rootRelation); 
 				} 
 			} 
 
@@ -725,7 +744,7 @@ namespace msXpSmineXpert
 	int
 		DataPlotWidgetRelationer::removeOrigin(AbstractPlotWidget *origin)
 		{
-			qInfo() << __FILE__ <<__LINE__ << __FUNCTION__;
+			qDebug() << __FILE__ <<__LINE__ << __FUNCTION__;
 
 			if(origin == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
