@@ -36,12 +36,12 @@
 
 
 ///////////////////////////// Local includes
-#include "DriftSpecPlotWidget.hpp"
-#include "DriftSpecWnd.hpp"
-#include "AnalysisPreferences.hpp"
-#include "MainWindow.hpp"
-#include "History.hpp"
-#include "MassDataIntegrator.hpp"
+#include <minexpert/gui/DriftSpecPlotWidget.hpp>
+#include <minexpert/gui/DriftSpecWnd.hpp>
+#include <minexpert/nongui/AnalysisPreferences.hpp>
+#include <minexpert/gui/MainWindow.hpp>
+#include <minexpert/nongui/History.hpp>
+#include <minexpert/nongui/MassDataIntegrator.hpp>
 
 
 namespace msXpSmineXpert
@@ -80,10 +80,13 @@ namespace msXpSmineXpert
 		: AbstractPlotWidget{parent, parentWnd, name,
 			desc, massSpecDataSet, fileName, isMultiGraph}
 	{
-		registerQtKey(Qt::Key_R); // to Tic chrom : RT
-		registerQtKey(Qt::Key_S); // to mass spec : MZ
-		registerQtKey(Qt::Key_I); // to intensity: I
-
+		AbstractPlotWidget::registerQtKeyCode(Qt::Key_R,
+			 	"Press T while right mouse click-drag to integrate to a XIC chromatogram");
+		AbstractPlotWidget::registerQtKeyCode(Qt::Key_S, 
+				"Press S while right mouse click-drag to integrate to a mass spectrum");
+		AbstractPlotWidget::registerQtKeyCode(Qt::Key_I,
+			 	"Press I while right mouse click-drag to integrate to a TIC intensity value");
+		
 		// Give the axes some labels:
 		xAxis->setLabel("drift time (ms)");
 		yAxis->setLabel("counts");
@@ -356,6 +359,12 @@ namespace msXpSmineXpert
 	void
 		DriftSpecPlotWidget::mouseReleaseHandledEvent(QMouseEvent *event)
 		{
+			if(m_isMultiGraph)
+			// All the actions below can only be performed if the plot widget has a
+			// knowledge of the mass spec data set. Thus, if *this plot widget is a
+			// multi-graph plot widget we need to return immediately.
+			return;
+
 			if(m_pressedKeyCode == Qt::Key_S && event->button() == Qt::RightButton)
 			{
 				integrateToMz(xRangeMin(), xRangeMax());
@@ -445,6 +454,12 @@ namespace msXpSmineXpert
 	double	
 		DriftSpecPlotWidget::integrateToTicIntensity(double lower, double upper)
 		{
+if(m_isMultiGraph)
+				// We cannot perform the action, because this plot widget has not mass
+				// spec data set pointer, it is a graph-only plot widget to display all
+				// the graphs overlaid.
+				return 0;
+
 			// Get the pointer to the x-axis (key axis).
 
 			QCPAxis *xAxis = graph()->keyAxis();
@@ -507,6 +522,16 @@ namespace msXpSmineXpert
 
 			QApplication::setOverrideCursor(QCursor(Qt::BusyCursor));
 
+			// Sanity check. It is not possible that this plot widget is not
+			// multi-graph and that at the same time, the mass spec data set pointer
+			// is nullptr.
+			
+			if(!m_isMultiGraph && mp_massSpecDataSet == Q_NULLPTR)
+				qFatal("Fatal error at %s@%d -- %s(). "
+						"Programming error."
+						"Program aborted.",
+						__FILE__, __LINE__, __FUNCTION__);
+
 			MassDataIntegrator integrator(mp_massSpecDataSet, localHistory);
 
 			integrator.integrateToTicIntensity();
@@ -531,6 +556,61 @@ namespace msXpSmineXpert
 		}
 
 
+	void
+		DriftSpecPlotWidget::newPlot()
+		{
+
+			// We only work on this if *this plot widget is *not* multigraph
+
+			if(m_isMultiGraph)
+				return;
+
+			MainWindow *mainWindow = static_cast<MainWindow *>(mp_parentWnd->parent());
+			QScriptContext *ctx = mainWindow->mp_scriptingWnd->m_scriptEngine.currentContext();
+
+			int argCount = ctx->argumentCount();
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()" 
+			//<< "argCount:" << argCount;
+
+			if(argCount != 1)
+			{
+				ctx->throwError("Syntax error: function newPlot() takes one Trace object as argument.");
+				return;
+			}
+
+			QScriptValue arg = ctx->argument(0);
+			QVariant variant = arg.data().toVariant();
+
+			if(!variant.isValid())	
+			{
+				ctx->throwError("Syntax error: function newPlot() takes one Trace object as argument.");
+				return;
+			}
+
+			if(variant.userType() == QMetaType::type("msXpSlibmass::Trace"))
+			{
+				msXpSlibmass::Trace trace(qscriptvalue_cast<msXpSlibmass::Trace>(arg));
+
+				// Get the color of the graph, so that we can print the stanza in
+				// the console window with the proper color.
+
+				QPen pen = graph()->pen();
+				QColor color = pen.color();
+
+				static_cast<TicChromWnd *>(mp_parentWnd)->newPlot(this, mp_massSpecDataSet,
+						QVector<double>::fromList(trace.keyList()), 
+						QVector<double>::fromList(trace.valList()),
+						"Trace from scripting environment.", m_history, color);
+			}
+			else
+			{
+				ctx->throwError("Syntax error: function newPlot() takes one Trace object as argument.");
+				return;
+			}
+		}
+
+
+
 	//! Key release event handler.
 	/*! 
 
@@ -607,8 +687,9 @@ namespace msXpSmineXpert
 						// mainWindow->m_ticChromVersusMassSpecMultiMap.key(massSpecPlotWidget);
 
 						// New version:
+						DataPlotWidgetRelation *p_rootRelation = Q_NULLPTR;
 						AbstractPlotWidget *rootPlotWidget =
-							mainWindow->m_dataPlotWidgetRelationer.rootPlotWidget(driftSpecPlotWidget);
+							mainWindow->m_dataPlotWidgetRelationer.rootPlotWidget(driftSpecPlotWidget, &p_rootRelation);
 
 						if(rootPlotWidget == Q_NULLPTR)
 						{
@@ -1009,9 +1090,11 @@ namespace msXpSmineXpert
 						// AbstractPlotWidget *originPlotWidget =
 						// mainWindow->m_ticChromVersusMassSpecMultiMap.key(massSpecPlotWidget);
 
+						DataPlotWidgetRelation *p_rootRelation = Q_NULLPTR;
+
 						AbstractPlotWidget *originPlotWidget =
 							mainWindow->m_dataPlotWidgetRelationer.rootPlotWidget(
-									driftSpecPlotWidget);
+									driftSpecPlotWidget, &p_rootRelation);
 
 						if(originPlotWidget == Q_NULLPTR)
 						{
