@@ -41,11 +41,11 @@
 #include <QClipboard>
 
 /////////////////////// Local includes
-#include "DriftSpecWnd.hpp"
-#include "MainWindow.hpp"
-#include "MassSpecDataFileLoaderSqlite3.hpp"
-#include "MassSpecDataFileLoaderPwiz.hpp"
-#include "MassDataIntegrator.hpp"
+#include <minexpert/gui/DriftSpecWnd.hpp>
+#include <minexpert/gui/MainWindow.hpp>
+#include <minexpert/nongui/MassSpecDataFileLoaderSqlite3.hpp>
+#include <minexpert/nongui/MassSpecDataFileLoaderPwiz.hpp>
+#include <minexpert/nongui/MassDataIntegrator.hpp>
 
 
 namespace msXpSmineXpert
@@ -154,7 +154,7 @@ namespace msXpSmineXpert
 		\param keyVector vector of double values to be used as the x-axis data.
 
 		\param valVector vector of double values to be used as the y-axis data.
-		
+
 		\param desc string containg the description of the plot.
 
 		\param massSpecDataSet the MassSpecDataSet instance in which the mass data
@@ -277,6 +277,9 @@ namespace msXpSmineXpert
 			connect(widget, &AbstractPlotWidget::updateStatusBarSignal, this,
 					&AbstractMultiPlotWnd::updateStatusBar);
 
+			connect(this, &AbstractMultiPlotWnd::showHelpSummarySignal,
+					widget, &AbstractPlotWidget::showHelpSummary);
+
 			return widget;
 		}
 
@@ -323,9 +326,9 @@ namespace msXpSmineXpert
 					&integrator,
 					&MassDataIntegrator::cancelOperation);
 
-			integrator.integrate();
+			bool res = integrator.integrate();
 
-			//qInfo() << "At this point the integration is finished. Desetup the feedback.";
+			//qDebug() << "At this point the integration is finished. Desetup the feedback.";
 
 			//De-setup the feedback.
 			QTimer::singleShot(2000, this, [=]() 
@@ -337,6 +340,14 @@ namespace msXpSmineXpert
 			// Make sure the cancel button is hidden.
 			mp_statusBarCancelPushButton->setVisible(false);
 
+			if(!res)
+			{
+				qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()" 
+					<< "The integration to Dt has created no drift spectrum.";
+
+				return;
+			}
+
 			// Create a text item to indicate the last history item.
 
 			QString historyItemText = history.newestHistoryItem()->asText(true /* brief */);
@@ -350,7 +361,7 @@ namespace msXpSmineXpert
 
 			DriftSpecPlotWidget *widget = static_cast<DriftSpecPlotWidget *>(
 					addPlotWidget(integrator.keyVector(), integrator.valVector(),
-					 	plotText, massSpecDataSet));
+						plotText, massSpecDataSet));
 
 			// The history that we get as a parameter needs to be appended to the new
 			// widget's history so that we have a full account of the history.
@@ -380,7 +391,7 @@ namespace msXpSmineXpert
 			// Ensure that there is a connection between this plot widget and this
 			// containing window, such that if there is a requirement to replot, the
 			// widget gets the signal.
-			
+
 			connect(this, &AbstractMultiPlotWnd::replotWithAxisRange, widget,
 					&AbstractPlotWidget::replotWithAxisRange);
 
@@ -408,6 +419,79 @@ namespace msXpSmineXpert
 		}
 
 
+	void
+		DriftSpecWnd::newPlot(AbstractPlotWidget *senderPlotWidget,
+				MassSpecDataSet *massSpecDataSet,
+				QVector<double> keys, QVector<double> values,
+				const QString &msg, History history, QColor color)
+		{
+			if(senderPlotWidget == Q_NULLPTR)
+				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
+
+			if(massSpecDataSet == Q_NULLPTR)
+				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
+
+			m_wishedColor = color;
+
+			// Create a text item to indicate the last history item.
+
+			QString historyItemText = history.newestHistoryItem()->asText(true /* brief */);
+
+			QString plotText = QString("%1\n%2 - %3\n%4")
+				.arg(massSpecDataSet->fileName())
+				.arg(m_desc)
+				.arg(historyItemText)
+				.arg(msg);
+
+			// Allocate the new plot widget in which the data are to be plot.
+
+			DriftSpecPlotWidget *widget = static_cast<DriftSpecPlotWidget *>(
+					addPlotWidget(keys, values, plotText, massSpecDataSet));
+
+			// The history that we get as a parameter needs to be appended to the new
+			// widget's history so that we have a full account of the history.
+
+			widget->rhistory().copyHistory(history, true /*remove duplicates*/);
+
+			MainWindow *mainWindow = static_cast<MainWindow *>(parent());
+			mainWindow->logConsoleMessage(widget->history().asText(
+						"Plot widget history: \n", "End plot widget history:\n"));
+			// And now only the innermost ranges of the whole history.
+			mainWindow->logConsoleMessage(widget->history().innermostRangesAsText());
+
+			// The plot widget reacts to the Qt::Key_Delete key by calling a function
+			// that emits a set of signals, of which the destroyPlotWidget signal
+			// actually indirectly triggers the destruction of the plot widget. This
+			// signal is now connected to the main window where a function will call for
+			// the destruction of all the target plot widgets, that is all the plot
+			// widgets that were created as the result of an integration computation of
+			// the plot widget currently being destroyed.
+
+			connect(widget, &AbstractPlotWidget::destroyPlotWidget, mainWindow,
+					&MainWindow::destroyAlsoAllTargetPlotWidgets);
+
+			connect(widget, &AbstractPlotWidget::toggleMultiGraphSignal,
+					mainWindow, &MainWindow::toggleMultiGraph);
+
+			// Ensure that there is a connection between this plot widget and this
+			// containing window, such that if there is a requirement to replot, the
+			// widget gets the signal.
+
+			connect(this, &AbstractMultiPlotWnd::replotWithAxisRange, widget,
+					&AbstractPlotWidget::replotWithAxisRange);
+
+			// Make sure we get the signal requiring to redraw the background of the
+			// widget, depending on it being focused or not.
+
+			connect(this, &AbstractMultiPlotWnd::redrawPlotBackground, widget,
+					&AbstractPlotWidget::redrawPlotBackground);
+
+			mainWindow->m_dataPlotWidgetRelationer.newRelation(
+					massSpecDataSet, senderPlotWidget, widget,
+					Q_NULLPTR /* open spectra dialog list widget item */);
+		}
+
+
 	//! Record an analysis stanza.
 	/*!
 
