@@ -49,27 +49,26 @@
 #include <QClipboard>
 
 
-//#include "qcustomplot-fr.hpp"
-#include "qcustomplot.h"
+#include <qcustomplot.h>
 
 /////////////////////// Local includes
-#include "MainWindow.hpp"
-#include "globals.hpp"
-#include "AboutMineXpertDlg.hpp"
-#include "Application.hpp"
-#include "libmass/MassSpectrum.hpp"
+#include <minexpert/gui/MainWindow.hpp>
+#include <minexpert/nongui/globals.hpp>
+#include <minexpert/gui/AboutMineXpertDlg.hpp>
+#include <minexpert/gui/Application.hpp>
+#include <libmass/MassSpectrum.hpp>
 
-#include "AbstractMultiPlotWnd.hpp"
+#include <minexpert/gui/AbstractMultiPlotWnd.hpp>
 
-#include "MassSpecDataFileFormatAnalyzer.hpp"
-#include "MassSpecDataFileLoaderSqlite3.hpp"
-#include "MassSpecDataFileLoaderPwiz.hpp"
-#include "MassSpecDataFileLoaderPwiz.hpp"
-#include "MassSpecDataFileLoaderMs1.hpp"
-#include "MassSpecDataFileLoaderXy.hpp"
-#include "MassSpecDataFileLoaderBrukerXy.hpp"
-#include "MassSpecDataFileLoaderDx.hpp"
-#include "libmassgui/ScriptingWnd.hpp"
+#include <minexpert/nongui/MassSpecDataFileFormatAnalyzer.hpp>
+#include <minexpert/nongui/MassSpecDataFileLoaderSqlite3.hpp>
+#include <minexpert/nongui/MassSpecDataFileLoaderPwiz.hpp>
+#include <minexpert/nongui/MassSpecDataFileLoaderPwiz.hpp>
+#include <minexpert/nongui/MassSpecDataFileLoaderMs1.hpp>
+#include <minexpert/nongui/MassSpecDataFileLoaderXy.hpp>
+#include <minexpert/nongui/MassSpecDataFileLoaderBrukerXy.hpp>
+#include <minexpert/nongui/MassSpecDataFileLoaderDx.hpp>
+#include <libmassgui/ScriptingWnd.hpp>
 
 
 
@@ -279,12 +278,6 @@ namespace msXpSmineXpert
 					QScriptEngine::ExcludeDeleteLater |
 					QScriptEngine::ExcludeSlots);
 
-			// mainWindow.quit()
-
-			mp_scriptingWnd->runScript("var quit = function() {mainWindow.quit()};",
-					"Make available \"mainWindow.quit() under alias quit().\n");
-
-
 			// consoleWnd 
 
 			mp_scriptingWnd->publishQObject(mp_consoleWnd, Q_NULLPTR /* parent QObject */,
@@ -376,6 +369,20 @@ namespace msXpSmineXpert
 					QScriptEngine::ExcludeDeleteLater |
 					QScriptEngine::ExcludeSlots);
 
+			// scriptingWnd 
+
+			mp_scriptingWnd->publishQObject(mp_scriptingWnd, Q_NULLPTR /* parent QObject */, 
+					"scriptingWnd", 
+					QString(), 
+					"Make available the scripting window under name \"scriptingWnd\".\n",
+					"The scripting window is the central place where scripting occurs. The "
+					"scripting window provides a number of features available to the scripter.",
+					scriptValue,
+					QScriptEngine::QtOwnership, 
+					QScriptEngine::ExcludeSuperClassContents |
+					QScriptEngine::ExcludeDeleteLater |
+					QScriptEngine::ExcludeSlots);
+
 			// data plot relationer
 
 			mp_scriptingWnd->publishQObject(&m_dataPlotWidgetRelationer, this,
@@ -549,7 +556,7 @@ namespace msXpSmineXpert
 			// color we wish for the plot.
 			mp_ticChromWnd->setWishedColor(*useColor);
 
-			qDebug() << __FILE__ << __LINE__ << "Calculating the TIC chromatogram...";
+			//qDebug() << __FILE__ << __LINE__ << "Calculating the TIC chromatogram...";
 
 			statusBarMessage("Calculating the TIC chromatogram...");
 			logConsoleMessage("Calculating the TIC chromatogram...\n");
@@ -640,8 +647,8 @@ namespace msXpSmineXpert
 			{
 				int format = MassSpecDataFileFormatAnalyzer::canLoadData(fileName);
 
-				qWarning() << __FILE__ << __LINE__ << __FUNCTION__
-					<< "Open file: " << fileName << "format:" << format;
+				//qWarning() << __FILE__ << __LINE__ << __FUNCTION__
+					//<< "Open file: " << fileName << "format:" << format;
 
 				// The strategy here is to go from more detailed formats to more generic
 				// ones, that'll speed the process.
@@ -652,8 +659,11 @@ namespace msXpSmineXpert
 				}
 				else if(format == MassSpecDataFileFormat::MASS_SPEC_DATA_FILE_FORMAT_MZML)
 				{
-					qWarning() << __FILE__ << __FILE__ << __FUNCTION__;
-					openMassSpectrometryFilePwiz(fileName, isStreamed);
+					openMassSpectrometryFilePwiz(fileName, format, isStreamed);
+				}
+				else if(format == MassSpecDataFileFormat::MASS_SPEC_DATA_FILE_FORMAT_MZXML)
+				{
+					openMassSpectrometryFilePwiz(fileName, format, isStreamed);
 				}
 				else if(format == MassSpecDataFileFormat::MASS_SPEC_DATA_FILE_FORMAT_DX)
 				{
@@ -823,7 +833,7 @@ namespace msXpSmineXpert
 
 */
 	void
-		MainWindow::openMassSpectrometryFilePwiz(QString fileName, bool isStreamed)
+		MainWindow::openMassSpectrometryFilePwiz(QString fileName, int format, bool isStreamed)
 		{
 			MassSpecDataFileLoaderPwiz loader(fileName);
 
@@ -876,8 +886,7 @@ namespace msXpSmineXpert
 			m_isOperationCancelled = false;
 
 			// We can set some more data to the massSpecDataSet:
-			massSpecDataSet->rfileFormat() =
-				MassSpecDataFileFormat::MASS_SPEC_DATA_FILE_FORMAT_MZML;
+			massSpecDataSet->rfileFormat() = format;
 
 			// When loading a new file, we want to first generate a TIC chromatogram
 			// for the user to start the investigation on its data.
@@ -1347,7 +1356,7 @@ namespace msXpSmineXpert
 			// color we wish for the plot.
 			mp_ticChromWnd->setWishedColor(*useColor);
 
-			qDebug() << __FILE__ << __LINE__ << "Calculating the TIC chromatogram...";
+			//qDebug() << __FILE__ << __LINE__ << "Calculating the TIC chromatogram...";
 
 			statusBarMessage("Calculating the TIC chromatogram...");
 			logConsoleMessage("Calculating the TIC chromatogram...\n");
@@ -1920,7 +1929,8 @@ namespace msXpSmineXpert
 			// We are getting a pointer to a plot widget that is being destroyed.
 			// That plot widget is not necessarily a root plot widget (but could be,
 			// so we need to be watching). What we want to do is trace down all the
-			// siblings of originPlotWidget (that is, targets).	
+			// descendants of originPlotWidget (that is, all the targets of
+			// originPlotWidget).	
 
 			if(originPlotWidget == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
@@ -1928,30 +1938,30 @@ namespace msXpSmineXpert
 			QString originPlotWidgetString = QString("0x%1").arg(
 					(quintptr)originPlotWidget, QT_POINTER_SIZE * 2, 16, QChar('0'));
 
-			qDebug()
-				<< __FILE__ << __LINE__
-				<< "Entering MainWindow::destroyAlsoAllTargetPlotWidgets with param:"
-				<< originPlotWidgetString << originPlotWidget << originPlotWidget->name()
-				<< originPlotWidget->desc() << "undergoing destruction."
-				<< "There are currently " << m_dataPlotWidgetRelationer.m_relationList.size()
-				<< "relations in total.";
+			//qDebug()
+				//<< __FILE__ << __LINE__
+				//<< "Entering MainWindow::destroyAlsoAllTargetPlotWidgets with param:"
+				//<< originPlotWidgetString << originPlotWidget << originPlotWidget->desc() 
+				//<< "undergoing destruction. There are currently " 
+				//<< m_dataPlotWidgetRelationer.m_relationList.size()
+				//<< "relations in total.";
 
 			// First off get the root plot widget and the root relation.
 
-			DataPlotWidgetRelation *rootRelation;
+			DataPlotWidgetRelation *p_rootRelation = Q_NULLPTR;
 
 			const AbstractPlotWidget *rootPlotWidget = 
-				m_dataPlotWidgetRelationer.rootPlotWidget(originPlotWidget, &rootRelation);
+				m_dataPlotWidgetRelationer.rootPlotWidget(originPlotWidget, &p_rootRelation);
 
 			// Sanity checks.
 
-			if(rootPlotWidget == Q_NULLPTR) qFatal("Fatal error at %s@%d -- %s. "
-
+			if(rootPlotWidget == Q_NULLPTR) 
+				qFatal("Fatal error at %s@%d -- %s. "
 					"It is not possible that a plot widget has no root plot widget."
 					"Program aborted.",
 					__FILE__, __LINE__, __FUNCTION__);
 
-			if(rootRelation == Q_NULLPTR)
+			if(p_rootRelation == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d -- %s. "
 						"It is not possible that no plot relation be found for a plot widget."
 						"Program aborted.",
@@ -1959,17 +1969,17 @@ namespace msXpSmineXpert
 
 			// Get all the relations that have originPlotWidget as origin plot widget:
 			// This means actually that we are gathering all the relations making
-			// originPlotWidget the parent of all the other siblings. We want to get a
-			// handle to the siblings by looking at the target plot widget member of
-			// all the returned relations.
+			// originPlotWidget the parent of all the descendants. We want to get a
+			// handle to the descendants by looking at the target plot widget member
+			// of all the returned relations.
 
 			QList<DataPlotWidgetRelation *> matchingOriginList;
 			m_dataPlotWidgetRelationer.getRelationsByOrigin(originPlotWidget,
 					&matchingOriginList);
 
-			qDebug() << __FILE__ << __LINE__ << "The plot widget being destroyed has "
-				<< matchingOriginList.size() << "target plot widgets (that is, siblings).\n"
-				<< "Going to iterate in the list of target plot widgets";
+			//qDebug() << __FILE__ << __LINE__ << "The plot widget being destroyed has "
+				//<< matchingOriginList.size() << "target plot widgets (that is, siblings).\n"
+				//<< "Going to iterate in the list of target plot widgets";
 
 			// Now, for each relation get the *target* widget and make sure we ask
 			// it to destroy itself.
@@ -1997,28 +2007,28 @@ namespace msXpSmineXpert
 							__FILE__, __LINE__, __FUNCTION__);
 				}
 
-				qDebug() << __FILE__ << __LINE__ << "Iteration " << iter
-					<< "relation: " << relation
-					<< "target plot widget:" << relation->targetPlotWidget()
-					<< "with name:" << relation->targetPlotWidget()->name();
+				//qDebug() << __FILE__ << __LINE__ << "Iteration " << iter
+					//<< "relation: " << relation
+					//<< "target plot widget:" << relation->targetPlotWidget()
+					//<< "with name:" << relation->targetPlotWidget()->name();
 
 				// Upon running the below function, the destroyed widget will become the
 				// originPlotWidget of a new function call to this function. This is
 				// recursive execution of the function until all the target widgets have
 				// lost their target widgets, and thus become origin plot widgets...
 
-				qDebug() << __FILE__ << __LINE__
-					<< "Going to call "
-					"relation->targetPlotWidget()->shouldDestroyPlotWidget"
-					<< "on" << relation->targetPlotWidget();
+				//qDebug() << __FILE__ << __LINE__
+					//<< "Going to call "
+					//"relation->targetPlotWidget()->shouldDestroyPlotWidget"
+					//<< "on" << relation->targetPlotWidget();
 
 				const_cast<AbstractPlotWidget *>(relation->targetPlotWidget())->shouldDestroyPlotWidget();
 			}
 			// End of
 			// for (int iter = 0; iter < matchingOriginList.size(); ++iter)
 
-			qDebug() << __FILE__ << __LINE__ << "Finished iterating in the list of "
-				"relations that match the origin plot " "widget.";
+			//qDebug() << __FILE__ << __LINE__ << "Finished iterating in the list of "
+				//"relations that match the origin plot " "widget.";
 
 			// At this point we have recursively destroyed all the descending plot
 			// widgets (siblings and downward siblings). What if the plot widget
@@ -2030,20 +2040,20 @@ namespace msXpSmineXpert
 			{
 				// Yes, the user is actually destroying the root plot widget.
 
-				qDebug() << __FILE__ << __LINE__
-					<< "Now handling the origin root plot widget case."
-					<< "Deleting the root plot widget and root relation:"
-					<< rootPlotWidget << rootPlotWidget->name() << "/"
-					<< rootRelation;
+				//qDebug() << __FILE__ << __LINE__
+					//<< "Now handling the origin root plot widget case."
+					//<< "Deleting the root plot widget and root relation:"
+					//<< rootPlotWidget << rootPlotWidget->name() << "/"
+					//<< p_rootRelation;
 
 				QColor color = rootPlotWidget->color();
 
 				// The root plot widget must have the open spectra dialog list
 				// widget item member datum set. Use it so that we can delete that item.
 
-				delete const_cast<QListWidgetItem *>(rootRelation->openSpectraListWidgetItem());
+				delete const_cast<QListWidgetItem *>(p_rootRelation->openSpectraListWidgetItem());
 
-				m_dataPlotWidgetRelationer.clearRelation(rootRelation);
+				m_dataPlotWidgetRelationer.clearRelation(p_rootRelation);
 				delete rootPlotWidget;
 				rootPlotWidget = Q_NULLPTR;
 
@@ -2071,18 +2081,18 @@ namespace msXpSmineXpert
 
 				m_dataPlotWidgetRelationer.clearRelation(matchingTargetList.first());
 
-				qDebug() << __FILE__ << __LINE__
-					<< "Now deleting the last leaf plot widget" << originPlotWidget
-					<< originPlotWidget->name() << originPlotWidget->desc();
+				//qDebug() << __FILE__ << __LINE__
+					//<< "Now deleting the last leaf plot widget" << originPlotWidget
+					//<< originPlotWidget->name() << originPlotWidget->desc();
 
 				delete originPlotWidget;
 				originPlotWidget = Q_NULLPTR;
 			}
 			else if(matchingTargetList.size() == 0)
 			{
-				qDebug() << __FILE__ << __LINE__ << "No matching target list, the "
-					"origin root plot widget was "
-					"deleted already.";
+				//qDebug() << __FILE__ << __LINE__ << "No matching target list, the "
+					//"origin root plot widget was "
+					//"deleted already.";
 			}
 		}
 
@@ -2208,9 +2218,9 @@ namespace msXpSmineXpert
 			// Now compute the TIC and plot it. The function returns the plot widget
 			// that displays the chromatogram for this mass spec data set.
 
-			qDebug() << __FILE__ << __LINE__ << "Calculating the TIC chromatogram...";
-			statusBarMessage("Calculating the TIC chromatogram...");
-			logConsoleMessage("Calculating the TIC chromatogram...\n");
+			//qDebug() << __FILE__ << __LINE__ << "Calculating the TIC chromatogram...";
+			//statusBarMessage("Calculating the TIC chromatogram...");
+			//logConsoleMessage("Calculating the TIC chromatogram...\n");
 
 			AbstractPlotWidget *widget =
 				mp_ticChromWnd->initialTic(massSpecDataSet);
@@ -2220,8 +2230,8 @@ namespace msXpSmineXpert
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 			}
 
-			qDebug() << __FILE__ << __LINE__
-				<< "Done calculating the TIC chromatogram...";
+			//qDebug() << __FILE__ << __LINE__
+				//<< "Done calculating the TIC chromatogram...";
 
 			statusBarMessage("Done calculating the TIC chromatogram...");
 			logConsoleMessage("Done calculating the TIC chromatogram...\n");
@@ -2259,8 +2269,8 @@ namespace msXpSmineXpert
 			AbstractPlotWidget *colorMapPlotWidget =
 				mp_colorMapWnd->initialColorMap(massSpecDataSet, &ok);
 
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ 
-				<< "fileName:" << massSpecDataSet->fileName();
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ 
+				//<< "fileName:" << massSpecDataSet->fileName();
 
 			if(colorMapPlotWidget == Q_NULLPTR)
 			{
@@ -2270,8 +2280,8 @@ namespace msXpSmineXpert
 				// The data were not from an ion mobility mass spectrometry experiment,
 				// so no problem.
 
-				qDebug() << __FILE__ << __LINE__
-					<< "Returned Q_NULLPTR color map widget. The data do not contain mobility data.";
+				//qDebug() << __FILE__ << __LINE__
+					//<< "Returned Q_NULLPTR color map widget. The data do not contain mobility data.";
 			}
 			else
 			{
