@@ -43,26 +43,26 @@
 
 
 /////////////////////// Local includes
-#include "globals.hpp"
+#include <minexpert/nongui/globals.hpp>
 
-#include "AnalysisPreferencesDlg.hpp"
-#include "AnalysisPreferencesDlg.hpp"
+#include <minexpert/gui/AnalysisPreferencesDlg.hpp>
+#include <minexpert/gui/AnalysisPreferencesDlg.hpp>
 
-#include "AbstractPlotWidget.hpp"
+#include <minexpert/gui/AbstractPlotWidget.hpp>
 
-#include "ConsoleWnd.hpp"
-#include "libmassgui/ScriptingWnd.hpp"
-#include "TicChromWnd.hpp"
-#include "DriftSpecWnd.hpp"
-#include "MassSpecWnd.hpp"
-#include "ColorMapWnd.hpp"
+#include <minexpert/gui/ConsoleWnd.hpp>
+#include <libmassgui/ScriptingWnd.hpp>
+#include <minexpert/gui/TicChromWnd.hpp>
+#include <minexpert/gui/DriftSpecWnd.hpp>
+#include <minexpert/gui/MassSpecWnd.hpp>
+#include <minexpert/gui/ColorMapWnd.hpp>
 
-#include "MassSpecDataSet.hpp"
-#include "OpenSpectraDlg.hpp"
+#include <minexpert/nongui/MassSpecDataSet.hpp>
+#include <minexpert/gui/OpenSpectraDlg.hpp>
 
-#include "MassSpecDataFileLoaderSqlite3.hpp"
+#include <minexpert/nongui/MassSpecDataFileLoaderSqlite3.hpp>
 
-#include "DataPlotWidgetRelation.hpp"
+#include <minexpert/gui/DataPlotWidgetRelation.hpp>
 
 
 namespace msXpSmineXpert
@@ -211,7 +211,7 @@ namespace msXpSmineXpert
 					bool isStreamed);
 
 			void openMassSpectrometryFileSqlite3(QString fileName, bool isStreamed = false);
-			void openMassSpectrometryFilePwiz(QString fileName, bool isStreamed = false);
+			void openMassSpectrometryFilePwiz(QString fileName, int format, bool isStreamed = false);
 			void openMassSpectrometryFileDx(QString fileName, bool isStreamed = false);
 			void openMassSpectrometryFileMs1(QString fileName, bool isStreamed = false);
 			void openMassSpectrometryFileBrukerXy(QString fileName, bool isStreamed = false);
