@@ -36,12 +36,12 @@
 
 
 ///////////////////////////// Local includes
-#include "MassSpecPlotWidget.hpp"
-#include "MassSpecWnd.hpp"
-#include "AnalysisPreferences.hpp"
-#include "MainWindow.hpp"
-#include "History.hpp"
-#include "MassDataIntegrator.hpp"
+#include <minexpert/gui/MassSpecPlotWidget.hpp>
+#include <minexpert/gui/MassSpecWnd.hpp>
+#include <minexpert/nongui/AnalysisPreferences.hpp>
+#include <minexpert/gui/MainWindow.hpp>
+#include <minexpert/nongui/History.hpp>
+#include <minexpert/nongui/MassDataIntegrator.hpp>
 
 
 namespace msXpSmineXpert
@@ -81,9 +81,12 @@ namespace msXpSmineXpert
 			AbstractPlotWidget{parent, parentWnd, name,
 				desc, massSpecDataSet, fileName, isMultiGraph}
 	{
-		registerQtKey(Qt::Key_R); // to Tic chrom : RT
-		registerQtKey(Qt::Key_D); // to drift spec : DT
-		registerQtKey(Qt::Key_I); // to intensity: I
+		AbstractPlotWidget::registerQtKeyCode(Qt::Key_R,
+			 	"Press T while right mouse click-drag to integrate to a XIC chromatogram");
+		AbstractPlotWidget::registerQtKeyCode(Qt::Key_D,
+			 	"Press D while right mouse click-drag to integrate to a drift spectrum");
+		AbstractPlotWidget::registerQtKeyCode(Qt::Key_I,
+			 	"Press I while right mouse click-drag to integrate to a TIC intensity value");
 
 		// Give the axes some labels:
 		xAxis->setLabel("m/z");
@@ -222,9 +225,9 @@ namespace msXpSmineXpert
 			// then we consider that the peaks do not belong to the same charge state
 			// envelope.
 
-			qDebug() << __FILE__ << __LINE__ << __FUNCTION__ 
-				<< "Charge:" << chargeIntPart
-				<< "Charge fractional part: " << chargeFracPart;
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ 
+			//<< "Charge:" << chargeIntPart
+			//<< "Charge fractional part: " << chargeFracPart;
 
 			if(chargeFracPart >= (1 - m_chargeFracPartTolerance /* that is >= 0.01 */) &&
 					chargeFracPart <= m_chargeFracPartTolerance /* that is <= 0.99 */)
@@ -684,6 +687,12 @@ namespace msXpSmineXpert
 	void
 		MassSpecPlotWidget::mouseReleaseHandledEvent(QMouseEvent *event)
 		{
+			if(m_isMultiGraph)
+				// All the actions below can only be performed if the plot widget has a
+				// knowledge of the mass spec data set. Thus, if *this plot widget is a
+				// multi-graph plot widget we need to return immediately.
+				return;
+
 			if(m_pressedKeyCode == Qt::Key_D && event->button() == Qt::RightButton)
 			{
 				integrateToDt(xRangeMin(), xRangeMax());
@@ -762,6 +771,9 @@ namespace msXpSmineXpert
 			// Aggreate the new item to the local history copy we made.
 			localHistory.appendHistoryItem(histItem);
 
+			// The signal is emitted, but the connection to the receiver exists only
+			// if this plot widget is NOT multi-graph. So, even if mp_massSpecDataSet
+			// is nullptr, there is no risk.
 			emit newTicChromatogram(mp_massSpecDataSet, "Calculating extracted ion chromatogram.",
 					localHistory, graph()->pen().color());
 		}
@@ -771,6 +783,12 @@ namespace msXpSmineXpert
 	double	
 		MassSpecPlotWidget::integrateToTicIntensity(double lower, double upper)
 		{
+			if(m_isMultiGraph)
+				// We cannot perform the action, because this plot widget has not mass
+				// spec data set pointer, it is a graph-only plot widget to display all
+				// the graphs overlaid.
+				return 0;
+
 			// Get the pointer to the x-axis (key axis).
 
 			QCPAxis *xAxis = graph()->keyAxis();
@@ -833,6 +851,16 @@ namespace msXpSmineXpert
 
 			QApplication::setOverrideCursor(QCursor(Qt::BusyCursor));
 
+			// Sanity check. It is not possible that this plot widget is not
+			// multi-graph and that at the same time, the mass spec data set pointer
+			// is nullptr.
+
+			if(!m_isMultiGraph && mp_massSpecDataSet == Q_NULLPTR)
+				qFatal("Fatal error at %s@%d -- %s(). "
+						"Programming error."
+						"Program aborted.",
+						__FILE__, __LINE__, __FUNCTION__);
+
 			MassDataIntegrator integrator(mp_massSpecDataSet, localHistory);
 
 			integrator.integrateToTicIntensity();
@@ -857,6 +885,105 @@ namespace msXpSmineXpert
 		}
 
 
+	//! Return a MassSpectrum crafted from the plot data.
+	msXpSlibmass::MassSpectrum 
+		MassSpecPlotWidget::massSpectrum(double lower, double upper)
+		{
+			msXpSlibmass::MassSpectrum massSpectrum;
+
+			// Iterate in the map and for each map item craft a MassPeak that is
+			// appended to the returned MassSpectrum.
+
+			if(m_isMultiGraph)
+				return msXpSlibmass::MassSpectrum();
+
+			QCPDataMap *data = graph()->data();
+
+			QList<double> keyList = data->keys();
+
+			for(int iter = 0; iter < keyList.size(); ++iter)
+			{
+				double mz = keyList.at(iter);
+				double i = data->value(mz).value;
+
+				if(!qIsNaN(lower))
+				{
+					if(mz < lower)
+						continue;
+				}
+				if(!qIsNaN(upper))
+				{
+
+					// plot data are sorted, so we can break for this condition.
+
+					if(mz > upper)
+						break;
+				}
+
+				// At this point, we are in the range, if one was defined.
+
+				massSpectrum.append(new msXpSlibmass::DataPoint(mz, i));
+			}
+
+			return massSpectrum;
+		}
+
+
+	void
+		MassSpecPlotWidget::newPlot()
+		{
+
+			// We only work on this if *this plot widget is *not* multigraph
+
+			if(m_isMultiGraph)
+				return;
+
+			MainWindow *mainWindow = static_cast<MainWindow *>(mp_parentWnd->parent());
+			QScriptContext *ctx = mainWindow->mp_scriptingWnd->m_scriptEngine.currentContext();
+
+			int argCount = ctx->argumentCount();
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()" 
+			//<< "argCount:" << argCount;
+
+			if(argCount != 1)
+			{
+				ctx->throwError("Syntax error: function newPlot() takes one Trace object as argument.");
+				return;
+			}
+
+			QScriptValue arg = ctx->argument(0);
+			QVariant variant = arg.data().toVariant();
+
+			if(!variant.isValid())	
+			{
+				ctx->throwError("Syntax error: function newPlot() takes one Trace object as argument.");
+				return;
+			}
+
+			if(variant.userType() == QMetaType::type("msXpSlibmass::Trace"))
+			{
+				msXpSlibmass::Trace trace(qscriptvalue_cast<msXpSlibmass::Trace>(arg));
+
+				// Get the color of the graph, so that we can print the stanza in
+				// the console window with the proper color.
+
+				QPen pen = graph()->pen();
+				QColor color = pen.color();
+
+				static_cast<MassSpecWnd *>(mp_parentWnd)->newPlot(this, mp_massSpecDataSet,
+						QVector<double>::fromList(trace.keyList()), 
+						QVector<double>::fromList(trace.valList()),
+						"Trace from scripting environment.", m_history, color);
+			}
+			else
+			{
+				ctx->throwError("Syntax error: function newPlot() takes one Trace object as argument.");
+				return;
+			}
+		}
+
+
+
 	//! Key release event handler.
 	/*! 
 
@@ -929,8 +1056,9 @@ namespace msXpSmineXpert
 						// mainWindow->m_ticChromVersusMassSpecMultiMap.key(massSpecPlotWidget);
 
 						// New version:
+						DataPlotWidgetRelation *p_rootRelation = Q_NULLPTR;
 						AbstractPlotWidget *ticChromPlotWidget =
-							mainWindow->m_dataPlotWidgetRelationer.rootPlotWidget(massSpecPlotWidget);
+							mainWindow->m_dataPlotWidgetRelationer.rootPlotWidget(massSpecPlotWidget, &p_rootRelation);
 
 						if(ticChromPlotWidget == nullptr)
 						{
@@ -1334,9 +1462,10 @@ namespace msXpSmineXpert
 						// *ticChromPlotWidget =
 						// mainWindow->m_ticChromVersusMassSpecMultiMap.key(massSpecPlotWidget);
 
+						DataPlotWidgetRelation *p_rootRelation = Q_NULLPTR;
 						AbstractPlotWidget *ticChromPlotWidget =
-							mainWindow->m_dataPlotWidgetRelationer.rootPlotWidget(
-									massSpecPlotWidget);
+							mainWindow->m_dataPlotWidgetRelationer.rootPlotWidget(massSpecPlotWidget, 
+									&p_rootRelation);
 
 						if(ticChromPlotWidget == nullptr)
 						{
