@@ -42,10 +42,10 @@
 
 
 /////////////////////// Local includes
-#include "AbstractPlotWidget.hpp"
-#include "MassSpecWnd.hpp"
-#include "MainWindow.hpp"
-#include "MassDataIntegrator.hpp"
+#include <minexpert/gui/AbstractPlotWidget.hpp>
+#include <minexpert/gui/MassSpecWnd.hpp>
+#include <minexpert/gui/MainWindow.hpp>
+#include <minexpert/nongui/MassDataIntegrator.hpp>
 
 
 namespace msXpSmineXpert
@@ -287,6 +287,9 @@ namespace msXpSmineXpert
 			connect(widget, &AbstractPlotWidget::updateStatusBarSignal, this,
 					&AbstractMultiPlotWnd::updateStatusBar);
 
+			connect(this, &AbstractMultiPlotWnd::showHelpSummarySignal,
+					widget, &AbstractPlotWidget::showHelpSummary);
+
 			return widget;
 		}
 
@@ -333,7 +336,7 @@ namespace msXpSmineXpert
 
 			integrator.integrate();
 
-			qInfo() << "At this point the integration is finished. Desetup the feedback.";
+			//qDebug() << "At this point the integration is finished. Desetup the feedback.";
 
 			//De-setup the feedback.
 			QTimer::singleShot(2000, this, [=]() 
@@ -416,6 +419,80 @@ namespace msXpSmineXpert
 		}
 
 
+	void
+		MassSpecWnd::newPlot(AbstractPlotWidget *senderPlotWidget,
+				MassSpecDataSet *massSpecDataSet,
+				QVector<double> keys, QVector<double> values,
+				const QString &msg, History history, QColor color)
+		{
+			if(senderPlotWidget == Q_NULLPTR)
+				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
+
+			if(massSpecDataSet == Q_NULLPTR)
+				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
+
+			m_wishedColor = color;
+
+			// Create a text item to indicate the last history item.
+
+			QString historyItemText = history.newestHistoryItem()->asText(true /* brief */);
+
+			QString plotText = QString("%1\n%2 - %3\n%4")
+				.arg(massSpecDataSet->fileName())
+				.arg(m_desc)
+				.arg(historyItemText)
+				.arg(msg);
+
+			// Allocate the new plot widget in which the data are to be plot.
+
+			MassSpecPlotWidget *widget = static_cast<MassSpecPlotWidget *>(
+					addPlotWidget(keys, values, plotText, massSpecDataSet));
+
+			// The history that we get as a parameter needs to be appended to the new
+			// widget's history so that we have a full account of the history.
+
+			widget->rhistory().copyHistory(history, true /*remove duplicates*/);
+
+			MainWindow *mainWindow = static_cast<MainWindow *>(parent());
+			mainWindow->logConsoleMessage(widget->history().asText(
+						"Plot widget history: \n", "End plot widget history:\n"));
+			// And now only the innermost ranges of the whole history.
+			mainWindow->logConsoleMessage(widget->history().innermostRangesAsText());
+
+			// The plot widget reacts to the Qt::Key_Delete key by calling a function
+			// that emits a set of signals, of which the destroyPlotWidget signal
+			// actually indirectly triggers the destruction of the plot widget. This
+			// signal is now connected to the main window where a function will call for
+			// the destruction of all the target plot widgets, that is all the plot
+			// widgets that were created as the result of an integration computation of
+			// the plot widget currently being destroyed.
+
+			connect(widget, &AbstractPlotWidget::destroyPlotWidget, mainWindow,
+					&MainWindow::destroyAlsoAllTargetPlotWidgets);
+
+			connect(widget, &AbstractPlotWidget::toggleMultiGraphSignal,
+					mainWindow, &MainWindow::toggleMultiGraph);
+
+			// Ensure that there is a connection between this plot widget and this
+			// containing window, such that if there is a requirement to replot, the
+			// widget gets the signal.
+
+			connect(this, &AbstractMultiPlotWnd::replotWithAxisRange, widget,
+					&AbstractPlotWidget::replotWithAxisRange);
+
+			// Make sure we get the signal requiring to redraw the background of the
+			// widget, depending on it being focused or not.
+
+			connect(this, &AbstractMultiPlotWnd::redrawPlotBackground, widget,
+					&AbstractPlotWidget::redrawPlotBackground);
+
+			mainWindow->m_dataPlotWidgetRelationer.newRelation(
+					massSpecDataSet, senderPlotWidget, widget,
+					Q_NULLPTR /* open spectra dialog list widget item */);
+		}
+
+
+
 	//! Record an analysis stanza.
 	/*!
 
