@@ -42,11 +42,11 @@
 
 
 /////////////////////// Local includes
-#include "OpenSpectraDlg.hpp"
-#include "MassSpecDataSet.hpp"
-#include "AbstractPlotWidget.hpp"
-#include "MainWindow.hpp"
-#include "DataPlotWidgetRelation.hpp"
+#include <minexpert/gui/OpenSpectraDlg.hpp>
+#include <minexpert/nongui/MassSpecDataSet.hpp>
+#include <minexpert/gui/AbstractPlotWidget.hpp>
+#include <minexpert/gui/MainWindow.hpp>
+#include <minexpert/gui/DataPlotWidgetRelation.hpp>
 
 
 namespace msXpSmineXpert
