@@ -36,14 +36,14 @@
 
 
 ///////////////////////////// Local includes
-#include "TicChromPlotWidget.hpp"
-#include "TicChromWnd.hpp"
-#include "AbstractMultiPlotWnd.hpp"
-#include "MassSpecSqlite3Handler.hpp"
-#include "AnalysisPreferences.hpp"
-#include "MainWindow.hpp"
-#include "History.hpp"
-#include "MassDataIntegrator.hpp"
+#include <minexpert/gui/TicChromPlotWidget.hpp>
+#include <minexpert/gui/TicChromWnd.hpp>
+#include <minexpert/gui/AbstractMultiPlotWnd.hpp>
+#include <minexpert/nongui/MassSpecSqlite3Handler.hpp>
+#include <minexpert/nongui/AnalysisPreferences.hpp>
+#include <minexpert/gui/MainWindow.hpp>
+#include <minexpert/nongui/History.hpp>
+#include <minexpert/nongui/MassDataIntegrator.hpp>
 
 
 namespace msXpSmineXpert
@@ -80,9 +80,12 @@ namespace msXpSmineXpert
 			name, desc, 
 			massSpecDataSet, fileName, isMultiGraph}
 	{
-		registerQtKey(Qt::Key_S); // to mass spectrum : MZ
-		registerQtKey(Qt::Key_D); // drift spectrum : DT
-		registerQtKey(Qt::Key_I); // to intensity: I
+		AbstractPlotWidget::registerQtKeyCode(Qt::Key_S, 
+				"Press S while right mouse click-drag to integrate to a mass spectrum");
+		AbstractPlotWidget::registerQtKeyCode(Qt::Key_D,
+				"Press D while right mouse click-drag to integrate to a drift spectrum");
+		AbstractPlotWidget::registerQtKeyCode(Qt::Key_I,
+				"Press I while right mouse click-drag to integrate to a TIC intensity value");
 
 		// Give the axes some labels:
 		xAxis->setLabel("time (min)");
@@ -115,14 +118,14 @@ namespace msXpSmineXpert
 			// This function might be called for a graph that sits in a single-graph
 			// plot widget or for a graph that sits in a multi-graph plot widget.
 			// Depending on the parameters, we'll know what is the case. If the
-			// parameters are not nullptr or empty, then the plot widget is a
+			// parameters are not Q_NULLPTR or empty, then the plot widget is a
 			// multi-graph plot widget and we need to set the data in the analysis
 			// record only for the graph
 			// passed as parameter.
 
-			QCPGraph *origGraph = nullptr;
+			QCPGraph *origGraph = Q_NULLPTR;
 
-			if(theGraph == nullptr)
+			if(theGraph == Q_NULLPTR)
 				origGraph = graph();
 			else
 				origGraph = theGraph;
@@ -145,11 +148,11 @@ namespace msXpSmineXpert
 			QString stanza;
 
 			TicChromWnd *wnd = dynamic_cast<TicChromWnd *>(mp_parentWnd);
-			if(wnd == nullptr)
+			if(wnd == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
 			const AnalysisPreferences *analPrefs = wnd->analysisPreferences();
-			if(analPrefs == nullptr)
+			if(analPrefs == Q_NULLPTR)
 				return stanza;
 
 			// The way we work here is that we get a format string that specifies how
@@ -164,7 +167,7 @@ namespace msXpSmineXpert
 			DataFormatStringSpecif *specif =
 				analPrefs->m_dataFormatStringSpecifHash.value(FormatType::DRIFT_SPEC);
 
-			if(specif == nullptr)
+			if(specif == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
 			// Handy local copy.
@@ -320,6 +323,17 @@ namespace msXpSmineXpert
 	void
 		TicChromPlotWidget::mouseReleaseHandledEvent(QMouseEvent *event)
 		{
+
+			// This function is called by 
+			// AbstractPlotWidget::mouseReleaseHandler(QMouseEvent *event) when 
+			// the key that is pressed is listed in the m_regQtKeyCodeList.
+
+			if(m_isMultiGraph)
+				// All the actions below can only be performed if the plot widget has a
+				// knowledge of the mass spec data set. Thus, if *this plot widget is a
+				// multi-graph plot widget we need to return immediately.
+				return;
+
 			if(m_pressedKeyCode == Qt::Key_S && event->button() == Qt::RightButton)
 			{
 				integrateToMz(xRangeMin(), xRangeMax());
@@ -406,6 +420,12 @@ namespace msXpSmineXpert
 	double
 		TicChromPlotWidget::integrateToTicIntensity(double lower, double upper)
 		{
+			if(m_isMultiGraph)
+				// We cannot perform the action, because this plot widget has not mass
+				// spec data set pointer, it is a graph-only plot widget to display all
+				// the graphs overlaid.
+				return 0;
+
 			// Get the pointer to the x-axis (key axis).
 
 			QCPAxis *xAxis = graph()->keyAxis();
@@ -468,6 +488,16 @@ namespace msXpSmineXpert
 
 			QApplication::setOverrideCursor(QCursor(Qt::BusyCursor));
 
+			// Sanity check. It is not possible that this plot widget is not
+			// multi-graph and that at the same time, the mass spec data set pointer
+			// is nullptr.
+
+			if(!m_isMultiGraph && mp_massSpecDataSet == Q_NULLPTR)
+				qFatal("Fatal error at %s@%d -- %s(). "
+						"Programming error."
+						"Program aborted.",
+						__FILE__, __LINE__, __FUNCTION__);
+
 			MassDataIntegrator integrator(mp_massSpecDataSet, localHistory);
 
 			integrator.integrateToTicIntensity();
@@ -492,6 +522,60 @@ namespace msXpSmineXpert
 		}
 
 
+	void
+		TicChromPlotWidget::newPlot()
+		{
+
+			// We only work on this if *this plot widget is *not* multigraph
+
+			if(m_isMultiGraph)
+				return;
+
+			MainWindow *mainWindow = static_cast<MainWindow *>(mp_parentWnd->parent());
+			QScriptContext *ctx = mainWindow->mp_scriptingWnd->m_scriptEngine.currentContext();
+
+			int argCount = ctx->argumentCount();
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()" 
+			//<< "argCount:" << argCount;
+
+			if(argCount != 1)
+			{
+				ctx->throwError("Syntax error: function newPlot() takes one Trace object as argument.");
+				return;
+			}
+
+			QScriptValue arg = ctx->argument(0);
+			QVariant variant = arg.data().toVariant();
+
+			if(!variant.isValid())	
+			{
+				ctx->throwError("Syntax error: function newPlot() takes one Trace object as argument.");
+				return;
+			}
+
+			if(variant.userType() == QMetaType::type("msXpSlibmass::Trace"))
+			{
+				msXpSlibmass::Trace trace(qscriptvalue_cast<msXpSlibmass::Trace>(arg));
+
+				// Get the color of the graph, so that we can print the stanza in
+				// the console window with the proper color.
+
+				QPen pen = graph()->pen();
+				QColor color = pen.color();
+
+				static_cast<TicChromWnd *>(mp_parentWnd)->newPlot(this, mp_massSpecDataSet,
+						QVector<double>::fromList(trace.keyList()), 
+						QVector<double>::fromList(trace.valList()),
+						"Trace from scripting environment.", m_history, color);
+			}
+			else
+			{
+				ctx->throwError("Syntax error: function newPlot() takes one Trace object as argument.");
+				return;
+			}
+		}
+
+
 	//! Key release event handler.
 	/*! 
 
@@ -546,9 +630,9 @@ namespace msXpSmineXpert
 						if(!iterGraph->visible())
 							continue;
 
-						// Get the color of the graph, so that we can print the stanza
-						// in
+						// Get the color of the graph, so that we can print the stanza in
 						// the console window with the proper color.
+
 						QPen curPen = iterGraph->pen();
 						QColor curColor = curPen.color();
 
@@ -558,7 +642,7 @@ namespace msXpSmineXpert
 						AbstractPlotWidget *ticChromPlotWidget =
 							parentWnd->monoGraphPlot(iterGraph);
 
-						if(ticChromPlotWidget == nullptr)
+						if(ticChromPlotWidget == Q_NULLPTR)
 						{
 							qFatal("Fatal error at %s@%d -- %s. "
 									"Cannot be that a multiGraph plot widget has not corresponding monoGraphPlot."
@@ -692,7 +776,7 @@ namespace msXpSmineXpert
 						AbstractPlotWidget *ticChromPlotWidget =
 							parentWnd->monoGraphPlot(iterGraph);
 
-						if(ticChromPlotWidget == nullptr)
+						if(ticChromPlotWidget == Q_NULLPTR)
 						{
 							qFatal("Fatal error at %s@%d -- %s. "
 									"Cannot be that a multiGraph plot widget has not corresponding monoGraphPlot."
