@@ -37,15 +37,15 @@
 
 
 /////////////////////// Local includes
-#include "globals.hpp"
-#include "TicChromWnd.hpp"
-#include "Application.hpp"
-#include "MainWindow.hpp"
-#include "libmass/MsMultiHash.hpp"
-#include "MassSpecDataFileLoaderPwiz.hpp"
-#include "MassSpecDataFileLoaderDx.hpp"
-#include "MassSpecDataFileLoaderMs1.hpp"
-#include "MassDataIntegrator.hpp"
+#include <minexpert/nongui/globals.hpp>
+#include <minexpert/gui/TicChromWnd.hpp>
+#include <minexpert/gui/Application.hpp>
+#include <minexpert/gui/MainWindow.hpp>
+#include <libmass/MsMultiHash.hpp>
+#include <minexpert/nongui/MassSpecDataFileLoaderPwiz.hpp>
+#include <minexpert/nongui/MassSpecDataFileLoaderDx.hpp>
+#include <minexpert/nongui/MassSpecDataFileLoaderMs1.hpp>
+#include <minexpert/nongui/MassDataIntegrator.hpp>
 
 
 #include <omp.h>
@@ -54,6 +54,8 @@ namespace msXpSmineXpert
 {
 
 
+	int type = qRegisterMetaType<QVector<double>>("QVector<double>");
+
 	//! Initialize the widget count to 0.
 	int TicChromWnd::widgetCounter = 0;
 
@@ -173,8 +175,10 @@ namespace msXpSmineXpert
 */	
 	TicChromPlotWidget *
 		TicChromWnd::addPlotWidget(const QVector<double> &keyVector,
-				const QVector<double> &valVector, const QString &desc,
-				MassSpecDataSet *massSpecDataSet, bool isMultiGraph)
+				const QVector<double> &valVector, 
+				const QString &desc,
+				MassSpecDataSet *massSpecDataSet, 
+				bool isMultiGraph)
 		{
 			MainWindow *mainWindow = static_cast<MainWindow *>(parent());
 
@@ -269,6 +273,9 @@ namespace msXpSmineXpert
 			connect(widget, &AbstractPlotWidget::updateStatusBarSignal, this,
 					&AbstractMultiPlotWnd::updateStatusBar);
 
+			connect(this, &AbstractMultiPlotWnd::showHelpSummarySignal,
+					widget, &TicChromPlotWidget::showHelpSummary);
+
 			return widget;
 		}
 
@@ -281,7 +288,7 @@ namespace msXpSmineXpert
 			integrator.initialTic();
 
 			History localHistory = integrator.history();
-			
+
 			// At this point what we should do is transfer the data to the plotting
 			// widget creation routine. Note that we are creating the very first plot
 			// widget with data just loaded from a mass spec file. That plot widget
@@ -304,9 +311,9 @@ namespace msXpSmineXpert
 
 			widget->rhistory().copyHistory(localHistory, true /*remove duplicates*/);
 
-			qDebug() << __FILE__ << __LINE__
-				<< "After initialTic was computed, history:"
-				<< widget->history().asText();
+			//qDebug() << __FILE__ << __LINE__
+			//<< "After initialTic was computed, history:"
+			//<< widget->history().asText();
 
 			// Log the history to the console.
 			MainWindow *mainWindow = static_cast<MainWindow *>(parent());
@@ -354,7 +361,7 @@ namespace msXpSmineXpert
 		}
 
 
-	//! Integrate data to TIC chromatogram starting from a mass spectrum.
+	//! Integrate data to TIC chromatogram.
 	/*!
 
 		\param massSpecDataSet pointer to the MassSpecDataSet where the mass data
@@ -398,7 +405,7 @@ namespace msXpSmineXpert
 
 			integrator.integrate();
 
-			qInfo() << "At this point the integration is finished. Desetup the feedback.";
+			//qDebug() << "At this point the integration is finished. Desetup the feedback.";
 
 			//De-setup the feedback.
 			QTimer::singleShot(2000, this, [=]() 
@@ -481,6 +488,80 @@ namespace msXpSmineXpert
 		}
 
 
+	void
+		TicChromWnd::newPlot(AbstractPlotWidget *senderPlotWidget,
+				MassSpecDataSet *massSpecDataSet,
+				QVector<double> keys, QVector<double> values,
+				const QString &msg, History history, QColor color)
+		{
+			if(senderPlotWidget == Q_NULLPTR)
+				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
+
+			if(massSpecDataSet == Q_NULLPTR)
+				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
+
+			m_wishedColor = color;
+
+			// Create a text item to indicate the last history item.
+
+			QString historyItemText = history.newestHistoryItem()->asText(true /* brief */);
+
+			QString plotText = QString("%1\n%2 - %3\n%4")
+				.arg(massSpecDataSet->fileName())
+				.arg(m_desc)
+				.arg(historyItemText)
+				.arg(msg);
+
+			// Allocate the new plot widget in which the data are to be plot.
+
+			TicChromPlotWidget *widget = static_cast<TicChromPlotWidget *>(
+					addPlotWidget(keys, values, plotText, massSpecDataSet));
+
+			// The history that we get as a parameter needs to be appended to the new
+			// widget's history so that we have a full account of the history.
+
+			widget->rhistory().copyHistory(history, true /*remove duplicates*/);
+
+			MainWindow *mainWindow = static_cast<MainWindow *>(parent());
+			mainWindow->logConsoleMessage(widget->history().asText(
+						"Plot widget history: \n", "End plot widget history:\n"));
+			// And now only the innermost ranges of the whole history.
+			mainWindow->logConsoleMessage(widget->history().innermostRangesAsText());
+
+			// The plot widget reacts to the Qt::Key_Delete key by calling a function
+			// that emits a set of signals, of which the destroyPlotWidget signal
+			// actually indirectly triggers the destruction of the plot widget. This
+			// signal is now connected to the main window where a function will call for
+			// the destruction of all the target plot widgets, that is all the plot
+			// widgets that were created as the result of an integration computation of
+			// the plot widget currently being destroyed.
+
+			connect(widget, &AbstractPlotWidget::destroyPlotWidget, mainWindow,
+					&MainWindow::destroyAlsoAllTargetPlotWidgets);
+
+			connect(widget, &AbstractPlotWidget::toggleMultiGraphSignal,
+					mainWindow, &MainWindow::toggleMultiGraph);
+
+			// Ensure that there is a connection between this plot widget and this
+			// containing window, such that if there is a requirement to replot, the
+			// widget gets the signal.
+
+			connect(this, &AbstractMultiPlotWnd::replotWithAxisRange, widget,
+					&AbstractPlotWidget::replotWithAxisRange);
+
+			// Make sure we get the signal requiring to redraw the background of the
+			// widget, depending on it being focused or not.
+
+			connect(this, &AbstractMultiPlotWnd::redrawPlotBackground, widget,
+					&AbstractPlotWidget::redrawPlotBackground);
+
+			mainWindow->m_dataPlotWidgetRelationer.newRelation(
+					massSpecDataSet, senderPlotWidget, widget,
+					Q_NULLPTR /* open spectra dialog list widget item */);
+		}
+
+
+
 	//! Toggle the visibility of the multigraph graph and the target widgets.
 	/*!
 
@@ -546,7 +627,6 @@ namespace msXpSmineXpert
 		}
 
 
-
 	//! Record an analysis stanza.
 	/*!
 
