@@ -71,6 +71,18 @@ namespace msXpSmineXpert
 	void printVersion();
 	void printConfig(const QString & = QString());
 
+// We need to redefine the way the version printing is performed because we want
+// to specify things that TCLAP cannot know (version of Qt being used, for
+// example).
+	class TCLAPOutput : public TCLAP::StdOutput
+	{
+		public:
+
+			virtual void version(CmdLineInterface& c)
+			{
+				printVersion();
+			}
+	};
 
 	void
 		printGreetings()
@@ -162,6 +174,10 @@ main(int argc, char **argv)
 
 		CmdLine cmdLine(cmdLineProgUsageMsg.toStdString(), ' ', VERSION);
 
+		msXpSmineXpert::TCLAPOutput myTCLAPOutput;
+
+		cmdLine.setOutput(&myTCLAPOutput);
+
 		// license switch
 		SwitchArg printLicenseArg(
 				"l", "license", "Print the license of this software.", cmdLine, false);
