@@ -35,7 +35,7 @@
 #include <QDebug>
 
 /////////////////////// Local includes
-#include "History.hpp"
+#include <minexpert/nongui/History.hpp>
 
 
 namespace msXpSmineXpert
@@ -568,8 +568,8 @@ namespace msXpSmineXpert
 				IntegrationRange *intRange = list.at(iter);
 				int intType = m_integrationMap.key(intRange);
 
-				qDebug() << __FILE__ << __LINE__
-					<< "Currently iterated intType:" << intType;
+				//qDebug() << __FILE__ << __LINE__
+					//<< "Currently iterated intType:" << intType;
 
 				IntegrationTypeDesc *intTypeDesc = m_intTypeDescMap.value(intType);
 
@@ -834,12 +834,12 @@ namespace msXpSmineXpert
 			QDateTime newestDateTime = m_historyItemList.first()->m_dateTime;
 			int newestDateTimeIndex = 0;
 
-			//qInfo() << __FILE__ << __LINE__ << __FUNCTION__ 
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ 
 				//<< "First history item:" << m_historyItemList.first()->asText();
 
 			for(int iter = 1; iter < m_historyItemList.size(); ++iter)
 			{
-				//qInfo() << __FILE__ << __LINE__ << __FUNCTION__ 
+				//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ 
 					//<< "iterating in second history item.";
 
 				HistoryItem *historyItem = m_historyItemList.at(iter);
@@ -848,7 +848,7 @@ namespace msXpSmineXpert
 
 				if(iterDateTime > newestDateTime)
 				{
-					//qInfo() << __FILE__ << __LINE__ << __FUNCTION__ 
+					//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ 
 						//<< "This history item is more recent:"
 						//<< historyItem->asText();
 
