@@ -33,19 +33,19 @@
 
 
 #include <qmath.h>
-#include "omp.h"
+#include <omp.h>
 
 #include <QDebug>
 #include <QTimer>
 
-#include "MassDataIntegrator.hpp"
-#include "MassSpectrum.hpp"
-#include "History.hpp"
+#include <minexpert/nongui/MassDataIntegrator.hpp>
+#include <libmass/MassSpectrum.hpp>
+#include <minexpert/nongui/History.hpp>
 
-#include "MassSpecDataFileLoaderPwiz.hpp"
-#include "MassSpecDataFileLoaderDx.hpp"
-#include "MassSpecDataFileLoaderMs1.hpp"
-#include "MassSpecDataFileLoaderSqlite3.hpp"
+#include <minexpert/nongui/MassSpecDataFileLoaderPwiz.hpp>
+#include <minexpert/nongui/MassSpecDataFileLoaderDx.hpp>
+#include <minexpert/nongui/MassSpecDataFileLoaderMs1.hpp>
+#include <minexpert/nongui/MassSpecDataFileLoaderSqlite3.hpp>
 
 
 namespace msXpSmineXpert
@@ -148,7 +148,7 @@ namespace msXpSmineXpert
 
 			const HistoryItem *newestHistoryItem = m_history.newestHistoryItem();
 
-			//qInfo() << __FILE__ << __LINE__ << __FUNCTION__ 
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ 
 			//<< "Newest history item:" << newestHistoryItem->asText();
 
 			// Now we need to know what is the integration type (or what are the
@@ -173,8 +173,8 @@ namespace msXpSmineXpert
 
 			int integrationType = integrationTypeList.first();
 
-			qInfo() << __FILE__ << __LINE__ << __FUNCTION__ 
-				<< "integration type:" << integrationType;
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ 
+			//<< "integration type:" << integrationType;
 
 			if(integrationType & ANY_TO_RT)
 				return integrateToRt();
@@ -271,13 +271,15 @@ namespace msXpSmineXpert
 
 
 	int
-		MassDataIntegrator::fillInDtMzHash(int* dtValues, int*mzCells, 
-				double *firstKey, double *lastKey, 
-				double *firstVal, double *lastVal)
+		MassDataIntegrator::fillInDtMzHash(int* p_dtValueCount, int*p_mzCells, 
+				double *p_firstKey, double *p_lastKey, 
+				double *p_firstVal, double *p_lastVal)
 		{
-			if(dtValues == Q_NULLPTR || mzCells == Q_NULLPTR ||
-					firstKey == Q_NULLPTR || lastKey == Q_NULLPTR ||
-					firstVal == Q_NULLPTR || lastVal == Q_NULLPTR)
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
+
+			if(p_dtValueCount == Q_NULLPTR || p_mzCells == Q_NULLPTR ||
+					p_firstKey == Q_NULLPTR || p_lastKey == Q_NULLPTR ||
+					p_firstVal == Q_NULLPTR || p_lastVal == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d -- %s. "
 						"The pointer(s) can not be nullptr."
 						"Program aborted.",
@@ -306,6 +308,9 @@ namespace msXpSmineXpert
 
 				int dtListSize = dtList.size();
 
+				//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()" 
+				//<< "The list of drift time values has " << dtListSize << "items";
+
 				if(dtListSize == 0)
 				{
 					// This is not intrinsically an error. It could be simply that the data
@@ -313,7 +318,7 @@ namespace msXpSmineXpert
 					return 0;
 				}
 
-				//qInfo() << __FILE__ << __LINE__
+				//qDebug() << __FILE__ << __LINE__
 				//<< "Number of drift time values:" << dtList.size()
 				//<< "from" << dtList.first() << "to" << dtList.last();
 
@@ -349,16 +354,16 @@ namespace msXpSmineXpert
 					// massSpecDataSet->m_dtHash contains all the (dt,spectra) pairs.
 					// Only get the list of spectra for the current dt.
 
-					msXpSlibmass::MassSpectrumList massSpectra(mp_massSpecDataSet->dtHash().values(dt));
+					QList<msXpSlibmass::MassSpectrum *> massSpectra = mp_massSpecDataSet->dtHash().values(dt);
 
-					int massSpectraSize = massSpectra.size();
+					int spectrumCount = massSpectra.size();
 
 #if 0
 					// That should not occur, because we do not store empty spectra when
 					// loading files.
 
 					// It might be that there are no spectra for a given dt value.
-					if(massSpectraSize == 0)
+					if(spectrumCount == 0)
 					{
 						qDebug() << __FILE__ << __LINE__ << __FUNCTION__ 
 							<< "For dt value" << dt << "there are no mass spectra.";
@@ -372,7 +377,7 @@ namespace msXpSmineXpert
 
 					msXpSlibmass::MassSpectrum *combinedMassSpectrum = new msXpSlibmass::MassSpectrum;
 
-					for(int jter = 0; jter < massSpectraSize; ++jter)
+					for(int jter = 0; jter < spectrumCount; ++jter)
 					{
 						combinedMassSpectrum->rdecimalPlaces() = 0;
 						combinedMassSpectrum->combine(*massSpectra.at(jter));
@@ -385,20 +390,23 @@ namespace msXpSmineXpert
 						mzCellNumber = massSpectrumSize;
 					}
 
-					if(combinedMassSpectrum->first()->mz() < minimumMz)
+					if(combinedMassSpectrum->first()->key() < minimumMz)
 					{
-						minimumMz = combinedMassSpectrum->first()->mz();
+						minimumMz = combinedMassSpectrum->first()->key();
 					}
 
-					if(combinedMassSpectrum->last()->mz() > maximumMz)
+					if(combinedMassSpectrum->last()->key() > maximumMz)
 					{
-						maximumMz = combinedMassSpectrum->last()->mz();
+						maximumMz = combinedMassSpectrum->last()->key();
 					}
 
 					// Now put the dt,spectrum pair in the hash that we'll later use to
 					// fill-in the colormap.
 					m_doubleMassSpecHash.insert(dt, combinedMassSpectrum);
 
+					//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()" 
+					//<< "The dtMsHash has " << m_doubleMassSpecHash.size() << "items";
+
 					emit updateFeedbackSignal(QString("dt: %1").arg(dt, 0, 'f', 6),
 							parsedDtValues, LogType::LOG_TO_STATUS_BAR);
 
@@ -409,7 +417,7 @@ namespace msXpSmineXpert
 				// End of
 				// for(; parsedDtValues < dtListSize; ++parsedDtValues)
 
-				//qInfo() << __FILE__ << __LINE__ << __FUNCTION__
+				//qDebug() << __FILE__ << __LINE__ << __FUNCTION__
 				//<< "size of the hash:" << m_doubleMassSpecHash.size();
 
 				// We may have gotten here because the operation was cancelled. In any case,
@@ -418,20 +426,27 @@ namespace msXpSmineXpert
 
 				// Set to the parameter slots the proper values.
 
-				*dtValues = parsedDtValues;
-				*mzCells = mzCellNumber;
+				*p_dtValueCount = parsedDtValues;
+				*p_mzCells = mzCellNumber;
 
-				*firstKey = dtList.first();
-				*lastKey = dtList.last();
+				*p_firstKey = dtList.first();
+				*p_lastKey = dtList.last();
 
-				*firstVal = minimumMz;
-				*lastVal = maximumMz;
+				*p_firstVal = minimumMz;
+				*p_lastVal = maximumMz;
 			}
 			else
 			{
-				streamFillInDtMzHash(dtValues, mzCells, 
-						firstKey, lastKey, 
-						firstVal, lastVal);
+				streamFillInDtMzHash(p_dtValueCount, p_mzCells, 
+						p_firstKey, p_lastKey, 
+						p_firstVal, p_lastVal);
+
+				// We need to set that variable value because that is returned later.
+				parsedDtValues = *p_dtValueCount;
+
+				//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()" 
+				//<< "The dtMsHash has " << m_doubleMassSpecHash.size() << "items."
+				//<< "That is (in/con)firmed with parsed dt values:" << parsedDtValues;
 			}
 
 			// At this point we have finished filling-in the dt/mass spectrum map.
@@ -444,10 +459,10 @@ namespace msXpSmineXpert
 			// integration ranges: the MZ range and the DT range.
 
 			histItem->newIntegrationRange(IntegrationType::DATA_TO_DT,
-					*firstKey, *lastKey);
+					*p_firstKey, *p_lastKey);
 
 			histItem->newIntegrationRange(IntegrationType::DATA_TO_MZ,
-					*firstVal, *lastVal);
+					*p_firstVal, *p_lastVal);
 
 			m_history.appendHistoryItem(histItem);
 
@@ -456,13 +471,15 @@ namespace msXpSmineXpert
 
 
 	int
-		MassDataIntegrator::streamFillInDtMzHash(int* dtValues, int*mzCells, 
-				double *firstKey, double *lastKey, 
-				double *firstVal, double *lastVal)
+		MassDataIntegrator::streamFillInDtMzHash(int *p_dtValueCount, int*p_mzCells, 
+				double *p_firstKey, double *p_lastKey, 
+				double *p_firstVal, double *p_lastVal)
 		{
-			if(dtValues == Q_NULLPTR || mzCells == Q_NULLPTR ||
-					firstKey == Q_NULLPTR || lastKey == Q_NULLPTR ||
-					firstVal == Q_NULLPTR || lastVal == Q_NULLPTR)
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()";
+
+			if(p_dtValueCount == Q_NULLPTR || p_mzCells == Q_NULLPTR ||
+					p_firstKey == Q_NULLPTR || p_lastKey == Q_NULLPTR ||
+					p_firstVal == Q_NULLPTR || p_lastVal == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d -- %s. "
 						"The pointer(s) can not be nullptr."
 						"Program aborted.",
@@ -483,6 +500,9 @@ namespace msXpSmineXpert
 
 			int dtListSize = dtList.size();
 
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()" 
+			//<< "The list of drift time values has " << dtListSize << "items";
+
 			if(dtListSize == 0)
 			{
 				// This is not intrinsically an error. It could be simply that the data
@@ -490,24 +510,24 @@ namespace msXpSmineXpert
 				return 0;
 			}
 
-			*dtValues = dtListSize;
+			*p_dtValueCount = dtListSize;
 
 			// Also, since we are in streamed mode, the data were already crunched
 			// on file load. Get a local handle by assignment (not deep copy).
 
 			m_doubleMassSpecHash = mp_massSpecDataSet->dtHash();
 
-			//qInfo() << "size of the hash:" << m_doubleMassSpecHash.size();
+			//qDebug() << "size of the hash:" << m_doubleMassSpecHash.size();
 
 			// Fill in the slots with data that were computed real time while
 			// loading the data in streamed mode.
-			*mzCells = mp_massSpecDataSet->mzCellCount();
+			*p_mzCells = mp_massSpecDataSet->mzCellCount();
 
-			*firstKey = dtList.first();
-			*lastKey = dtList.last();
+			*p_firstKey = dtList.first();
+			*p_lastKey = dtList.last();
 
-			*firstVal = mp_massSpecDataSet->mzRangeStart();
-			*lastVal = mp_massSpecDataSet->mzRangeEnd();
+			*p_firstVal = mp_massSpecDataSet->mzRangeStart();
+			*p_lastVal = mp_massSpecDataSet->mzRangeEnd();
 
 			return dtListSize;
 		}
@@ -559,7 +579,7 @@ namespace msXpSmineXpert
 			mzIntegration = m_history.innermostMzRange(&mzStart, &mzEnd);
 			dtIntegration = m_history.innermostDtRange(&dtStart, &dtEnd);
 
-			//qInfo("rtIntegration: [%.6f-%.6f] \n"
+			//qDebug("rtIntegration: [%.6f-%.6f] \n"
 			//"mzIntegratin: [%.6f-%.6f] \n"
 			//"dtIntegration: [%.6f-%.6f] \n", 
 			//rtStart, rtEnd, 
@@ -616,7 +636,7 @@ namespace msXpSmineXpert
 
 				double rt = rtList.at(iter);
 
-				msXpSlibmass::MassSpectrumList rtMassSpectra(rtHash.values(rt));
+				QList<msXpSlibmass::MassSpectrum*> rtMassSpectra(rtHash.values(rt));
 
 				if(dtIntegration)
 				{
@@ -638,9 +658,9 @@ namespace msXpSmineXpert
 					double newTic = 0.0;
 
 					if(mzIntegration)
-						newTic = rtMassSpectra.at(kter)->tic(mzStart, mzEnd);
+						newTic = rtMassSpectra.at(kter)->valSum(mzStart, mzEnd);
 					else
-						newTic = rtMassSpectra.at(kter)->tic();
+						newTic = rtMassSpectra.at(kter)->valSum();
 
 					// Had another spectrum by the same rt already been iterated in?
 
@@ -699,7 +719,7 @@ namespace msXpSmineXpert
 				// qDebug() << __FILE__ << __LINE__ << "Need to fake some data";
 
 				const msXpSlibmass::MassSpectrum *massSpectrum = mp_massSpecDataSet->massSpectrum(0);
-				double ticIntensity = massSpectrum->tic();
+				double ticIntensity = massSpectrum->valSum();
 
 				m_keyVector.append(1.0);
 				m_valVector.append(ticIntensity);
@@ -802,7 +822,7 @@ namespace msXpSmineXpert
 				// qDebug() << __FILE__ << __LINE__ << "Need to fake some data";
 
 				const msXpSlibmass::MassSpectrum *massSpectrum = mp_massSpecDataSet->massSpectrum(0);
-				double ticIntensity = massSpectrum->tic();
+				double ticIntensity = massSpectrum->valSum();
 
 				m_keyVector.append(1.0);
 				m_valVector.append(ticIntensity);
@@ -858,7 +878,7 @@ namespace msXpSmineXpert
 			mzIntegration = m_history.innermostMzRange(&mzStart, &mzEnd);
 			dtIntegration = m_history.innermostDtRange(&dtStart, &dtEnd);
 
-			//qInfo("rtIntegration: [%.6f-%.6f] \n"
+			//qDebug("rtIntegration: [%.6f-%.6f] \n"
 			//"mzIntegratin: [%.6f-%.6f] \n"
 			//"dtIntegration: [%.6f-%.6f] \n", 
 			//rtStart, rtEnd, 
@@ -919,7 +939,7 @@ namespace msXpSmineXpert
 
 				// Get a list of all the mass spectra having the same key value.
 
-				msXpSlibmass::MassSpectrumList rtMassSpectra(rtHash.values(rt));
+				QList<msXpSlibmass::MassSpectrum *> rtMassSpectra(rtHash.values(rt));
 
 				if(dtIntegration)
 				{
@@ -964,8 +984,8 @@ namespace msXpSmineXpert
 			// and of
 			// #pragma omp parallel for
 
-			m_keyVector = QVector<double>::fromList(combinedMassSpectrum.mzList());
-			m_valVector = QVector<double>::fromList(combinedMassSpectrum.iList());
+			m_keyVector = QVector<double>::fromList(combinedMassSpectrum.keyList());
+			m_valVector = QVector<double>::fromList(combinedMassSpectrum.valList());
 
 			// Sanity check
 			if(m_keyVector.size() != m_valVector.size())
@@ -1105,6 +1125,12 @@ namespace msXpSmineXpert
 	bool 
 		MassDataIntegrator::integrateToDt()
 		{
+
+			// Only do something if the data set contains ion mobility data.
+
+			if(!mp_massSpecDataSet->isMobilityExperiment())
+				return false; 
+
 			if(mp_massSpecDataSet->isStreamed())
 				return streamIntegrateToDt();
 
@@ -1147,7 +1173,7 @@ namespace msXpSmineXpert
 			mzIntegration = m_history.innermostMzRange(&mzStart, &mzEnd);
 			dtIntegration = m_history.innermostDtRange(&dtStart, &dtEnd);
 
-			//qInfo("rtIntegration: [%.6f-%.6f] \n"
+			//qDebug("rtIntegration: [%.6f-%.6f] \n"
 			//"mzIntegration: [%.6f-%.6f] \n"
 			//"dtIntegration: [%.6f-%.6f] \n", 
 			//rtStart, rtEnd, 
@@ -1208,7 +1234,7 @@ namespace msXpSmineXpert
 
 				double rt = rtList.at(iter);
 
-				msXpSlibmass::MassSpectrumList rtMassSpectra(rtHash.values(rt));
+				QList<msXpSlibmass::MassSpectrum *> rtMassSpectra(rtHash.values(rt));
 
 				if(dtIntegration)
 				{
@@ -1216,6 +1242,7 @@ namespace msXpSmineXpert
 					{
 						msXpSlibmass::MassSpectrum *spectrum = rtMassSpectra.at(jter);
 
+
 						if(spectrum->dt() < dtStart || spectrum->dt() > dtEnd)
 						{
 							rtMassSpectra.removeAt(jter);
@@ -1231,9 +1258,9 @@ namespace msXpSmineXpert
 					double newTic = 0.0;
 
 					if(mzIntegration)
-						newTic = spectrum->tic(mzStart, mzEnd);
+						newTic = spectrum->valSum(mzStart, mzEnd);
 					else
-						newTic = spectrum->tic();
+						newTic = spectrum->valSum();
 
 					// Had another spectrum by the same dt already been iterated in?
 
@@ -1353,6 +1380,12 @@ namespace msXpSmineXpert
 	bool
 		MassDataIntegrator::integrateToTicIntensity()
 		{
+			if(mp_massSpecDataSet == Q_NULLPTR)
+				qFatal("Fatal error at %s@%d -- %s(). "
+						"The mass spec data set pointer cannot be nullptr here."
+						"Program aborted.",
+						__FILE__, __LINE__, __FUNCTION__);
+
 			if(mp_massSpecDataSet->isStreamed())
 				return streamIntegrateToTicIntensity();
 
@@ -1444,7 +1477,7 @@ namespace msXpSmineXpert
 
 				double rt = rtList.at(iter);
 
-				msXpSlibmass::MassSpectrumList rtMassSpectra(rtHash.values(rt));
+				QList<msXpSlibmass::MassSpectrum *> rtMassSpectra(rtHash.values(rt));
 
 				if(dtIntegration)
 				{
@@ -1466,9 +1499,9 @@ namespace msXpSmineXpert
 					double newTic = 0.0;
 
 					if(mzIntegration)
-						newTic = rtMassSpectra.at(kter)->tic(mzStart, mzEnd);
+						newTic = rtMassSpectra.at(kter)->valSum(mzStart, mzEnd);
 					else
-						newTic = rtMassSpectra.at(kter)->tic();
+						newTic = rtMassSpectra.at(kter)->valSum();
 
 #pragma omp critical
 					localIntensity += newTic;
@@ -1507,6 +1540,12 @@ namespace msXpSmineXpert
 	bool	
 		MassDataIntegrator::streamIntegrateToTicIntensity()
 		{
+			if(mp_massSpecDataSet == Q_NULLPTR)
+				qFatal("Fatal error at %s@%d -- %s(). "
+						"The mass spec data set pointer cannot be nullptr here."
+						"Program aborted.",
+						__FILE__, __LINE__, __FUNCTION__);
+
 			m_keyVector.clear();
 			m_valVector.clear();
 
@@ -1641,7 +1680,7 @@ namespace msXpSmineXpert
 		MassDataIntegrator::setupFeedbackRelay(QString msg, int startValue, int endValue,
 				int currentValue, int logType)
 		{
-			//qInfo() << "Relaying setup feedback signal:" << msg;
+			//qDebug() << "Relaying setup feedback signal:" << msg;
 			emit setupFeedbackSignal(msg, startValue, endValue, currentValue, logType);
 		}
 
@@ -1651,7 +1690,7 @@ namespace msXpSmineXpert
 		MassDataIntegrator::updateFeedbackRelay(QString msg, int currentValue,
 				int logType)
 		{
-			//qInfo() << "Relaying update feedback signal:" << msg;
+			//qDebug() << "Relaying update feedback signal:" << msg;
 			emit updateFeedbackSignal(msg , currentValue, logType);
 		}
 
