@@ -41,8 +41,8 @@
 
 
 ////////////////////////////// local includes
-#include "MassSpecDataFileLoaderDx.hpp"
-#include "globals.hpp"
+#include <minexpert/nongui/MassSpecDataFileLoaderDx.hpp>
+#include <minexpert/nongui/globals.hpp>
 
 
 namespace msXpSmineXpert
@@ -286,7 +286,7 @@ namespace msXpSmineXpert
 				// process these by creating a mass peak that we can append to the
 				// spectrum that we allocated at the beginning of this function.
 
-				msXpSlibmass::MassPeak *massPeak = new msXpSlibmass::MassPeak(mz, i);
+				msXpSlibmass::DataPoint *massPeak = new msXpSlibmass::DataPoint(mz, i);
 				massSpectrum->append(massPeak);
 
 				// qDebug() << __FILE__ << __LINE__ << "Appending new massPeak for
@@ -523,7 +523,7 @@ namespace msXpSmineXpert
 						// We are reading in streamed mode. This is the chance we
 						// have to compute the TIC for the spectrum:
 
-						double newTic = newSpectrum->tic();
+						double newTic = newSpectrum->valSum();
 
 						// Had already another spectrum have the same rt ? If so
 						// another TIC was already computed.
@@ -900,11 +900,11 @@ namespace msXpSmineXpert
 			// while(!file.atEnd())
 
 			if(intensity != Q_NULLPTR)
-				*intensity = combinedMassSpectrum.tic();
+				*intensity = combinedMassSpectrum.valSum();
 			else
 			{
-				*keyVector = QVector<double>::fromList(combinedMassSpectrum.mzList());
-				*valVector = QVector<double>::fromList(combinedMassSpectrum.iList());
+				*keyVector = QVector<double>::fromList(combinedMassSpectrum.keyList());
+				*valVector = QVector<double>::fromList(combinedMassSpectrum.valList());
 			}
 
 			file.close();
