@@ -31,7 +31,7 @@
  */
 
 
-#include "omp.h"
+#include <omp.h>
 
 #include <QtSql>
 #include <QSqlDatabase>
@@ -39,11 +39,12 @@
 #include <QFile>
 #include <QByteArray>
 
-#include "MassSpecDataFileLoaderPwiz.hpp"
-#include "MassSpecFileMetaData.hpp"
+#include <minexpert/nongui/MassSpecDataFileLoaderPwiz.hpp>
+#include <minexpert/nongui/MassSpecFileMetaData.hpp>
+#include <libmass/MassSpectrum.hpp>
 
-#include "pwiz/data/msdata/MSDataFile.hpp"
-#include "pwiz/data/msdata/DefaultReaderList.hpp"
+#include <pwiz/data/msdata/MSDataFile.hpp>
+#include <pwiz/data/msdata/DefaultReaderList.hpp>
 
 using namespace pwiz::msdata;
 
@@ -397,7 +398,7 @@ namespace msXpSmineXpert
 				// mp_massSpecDataSet->m_ticChromMap. This is the chance we have to
 				// compute the TIC for the spectrum:
 
-				double newTic = mp_newSpectrum->tic();
+				double newTic = mp_newSpectrum->valSum();
 
 				// Had already another spectrum have the same rt ? If so another
 				// TIC was
@@ -417,7 +418,7 @@ namespace msXpSmineXpert
 				}
 
 				//// Only for debugging purposes:
-				// double tic = mp_newSpectrum->tic();
+				// double tic = mp_newSpectrum->valSum();
 
 				// qDebug() << __FILE__ << __LINE__
 				//<< "TIC value:" << tic;
@@ -445,7 +446,8 @@ namespace msXpSmineXpert
 					// combinations).
 
 					msXpSlibmass::MassSpectrum *massSpectrum =
-						mp_massSpecDataSet->m_dtHash.value(m_curDriftTime, Q_NULLPTR);
+						static_cast<msXpSlibmass::MassSpectrum *>(
+								mp_massSpecDataSet->m_dtHash.value(m_curDriftTime, Q_NULLPTR));
 
 					if(massSpectrum == Q_NULLPTR)
 					{
@@ -487,11 +489,11 @@ namespace msXpSmineXpert
 						// Finally, let's store the first mz value and the last one.  Only
 						// if the values need an update.
 
-						double mz_first = newSpectrum->first()->mz();
+						double mz_first = newSpectrum->first()->key();
 						if(mz_first < mp_massSpecDataSet->m_mzRangeStart)
 							mp_massSpecDataSet->m_mzRangeStart = mz_first;
 
-						double mz_last = newSpectrum->last()->mz();
+						double mz_last = newSpectrum->last()->key();
 						if(mz_last > mp_massSpecDataSet->m_mzRangeEnd)
 							mp_massSpecDataSet->m_mzRangeEnd = mz_last;
 
@@ -524,11 +526,11 @@ namespace msXpSmineXpert
 						// one.
 						// Only if the values need an update.
 
-						double mz_first = massSpectrum->first()->mz();
+						double mz_first = massSpectrum->first()->key();
 						if(mz_first < mp_massSpecDataSet->m_mzRangeStart)
 							mp_massSpecDataSet->m_mzRangeStart = mz_first;
 
-						double mz_last = massSpectrum->last()->mz();
+						double mz_last = massSpectrum->last()->key();
 						if(mz_last > mp_massSpecDataSet->m_mzRangeEnd)
 							mp_massSpecDataSet->m_mzRangeEnd = mz_last;
 
@@ -560,7 +562,7 @@ namespace msXpSmineXpert
 				mp_massSpecDataSet->insertRtHash(m_scanStartTime, mp_newSpectrum);
 
 				//// Only for debugging purposes:
-				// double tic = mp_newSpectrum->tic();
+				// double tic = mp_newSpectrum->valSum();
 
 				// qDebug() << __FILE__ << __LINE__
 				//<< "TIC value:" << tic;
@@ -619,8 +621,8 @@ namespace msXpSmineXpert
 	int
 		MassSpecDataFileLoaderPwiz::loadSpectrumToVectors()
 		{
-			//qInfo() << __FILE__ << __LINE__ << __FUNCTION__
-				//<< "m_integrationType:" << m_integrationType;
+			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__
+			//<< "m_integrationType:" << m_integrationType;
 
 			if(m_integrationType == IntegrationType::ANY_TO_RT)
 			{
@@ -668,7 +670,7 @@ namespace msXpSmineXpert
 	int
 		MassSpecDataFileLoaderPwiz::loadSpectrumToXyFilesInSequence()
 		{
-			QString *text = mp_newSpectrum->asText();
+			QString *text = mp_newSpectrum->asText(-1, -1);
 
 			if(text == Q_NULLPTR)
 				return -1;
@@ -831,10 +833,10 @@ namespace msXpSmineXpert
 				// We need to integrate the intensity of the various mass peaks of the
 				// spectrum into the TIC, but only for the mz integration range.
 
-				newTic = mp_newSpectrum->tic(mzStart, mzEnd);
+				newTic = mp_newSpectrum->valSum(mzStart, mzEnd);
 			}
 			else
-				newTic = mp_newSpectrum->tic();
+				newTic = mp_newSpectrum->valSum();
 
 			// Now check if there was already a mass spectrum that was processed with
 			// the same m_scanStartTime (which should occur if the mass spectra were
@@ -897,8 +899,8 @@ namespace msXpSmineXpert
 			rtIntegration = m_history.innermostRtRange(&rtStart, &rtEnd);
 			if(rtIntegration)
 			{
-				//qInfo() << __FILE__ << __LINE__ << "rt integration accounted for: \n"
-					//<< QString("[%1-%2]\n").arg(rtStart).arg(rtEnd);
+				//qDebug() << __FILE__ << __LINE__ << "rt integration accounted for: \n"
+				//<< QString("[%1-%2]\n").arg(rtStart).arg(rtEnd);
 			}
 
 			// MZ integration.
@@ -910,8 +912,8 @@ namespace msXpSmineXpert
 			mzIntegration = m_history.innermostMzRange(&mzStart, &mzEnd);
 			if(mzIntegration)
 			{
-				//qInfo() << __FILE__ << __LINE__ << "mz integration accounted for: \n"
-					//<< QString("[%1-%2]\n").arg(mzStart).arg(mzEnd);
+				//qDebug() << __FILE__ << __LINE__ << "mz integration accounted for: \n"
+				//<< QString("[%1-%2]\n").arg(mzStart).arg(mzEnd);
 			}
 
 			// DT integration.
@@ -926,8 +928,8 @@ namespace msXpSmineXpert
 			dtIntegration = m_history.innermostDtRange(&dtStart, &dtEnd);
 			if(dtIntegration)
 			{
-				//qInfo() << __FILE__ << __LINE__ << "dt integration accounted for: \n"
-					//<< QString("[%1-%2]\n").arg(dtStart).arg(dtEnd);
+				//qDebug() << __FILE__ << __LINE__ << "dt integration accounted for: \n"
+				//<< QString("[%1-%2]\n").arg(dtStart).arg(dtEnd);
 			}
 
 			// We just have parsed a spectrum and we have all there relevant data in the
@@ -939,9 +941,9 @@ namespace msXpSmineXpert
 			{
 				if(m_scanStartTime < rtStart || m_scanStartTime > rtEnd)
 				{
-					//qInfo() << __FILE__ << __LINE__ << "returning because "
-						//"m_scanStartTime < rtStart || "
-						//"m_scanStartTime > rtEnd";
+					//qDebug() << __FILE__ << __LINE__ << "returning because "
+					//"m_scanStartTime < rtStart || "
+					//"m_scanStartTime > rtEnd";
 
 					return 0;
 				}
@@ -950,9 +952,9 @@ namespace msXpSmineXpert
 			{
 				if(m_curDriftTime < dtStart || m_curDriftTime > dtEnd)
 				{
-					//qInfo() << __FILE__ << __LINE__ << "returning because "
-						//"m_curDriftTime < dtStart || "
-						//"m_curDriftTime > dtEnd";
+					//qDebug() << __FILE__ << __LINE__ << "returning because "
+					//"m_curDriftTime < dtStart || "
+					//"m_curDriftTime > dtEnd";
 
 					return 0;
 				}
@@ -961,8 +963,8 @@ namespace msXpSmineXpert
 			if(mp_newSpectrum == Q_NULLPTR)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
-			//qInfo() << __FILE__ << __LINE__
-				//<< "mp_newSpectrum has size:" << mp_newSpectrum->size();
+			//qDebug() << __FILE__ << __LINE__
+			//<< "mp_newSpectrum has size:" << mp_newSpectrum->size();
 
 			// Now the more specific mz integration
 			if(mzIntegration)
@@ -972,8 +974,8 @@ namespace msXpSmineXpert
 			else
 				m_massSpectrum.combine(*mp_newSpectrum);
 
-			//qInfo() << __FILE__ << __LINE__
-				//<< "m_massSpectrum has size:" << m_massSpectrum.size();
+			//qDebug() << __FILE__ << __LINE__
+			//<< "m_massSpectrum has size:" << m_massSpectrum.size();
 
 			return 1;
 		}
@@ -1112,10 +1114,10 @@ namespace msXpSmineXpert
 				// We need to integrate the intensity of the various mass peaks of the
 				// spectrum into the TIC, but only for the mz integration range.
 
-				newTic = mp_newSpectrum->tic(mzStart, mzEnd);
+				newTic = mp_newSpectrum->valSum(mzStart, mzEnd);
 			}
 			else
-				newTic = mp_newSpectrum->tic();
+				newTic = mp_newSpectrum->valSum();
 
 			// Now check if there was already a mass spectrum that was processed with
 			// the same m_curDriftTime (which should occur if the mass spectra were
@@ -1183,7 +1185,7 @@ namespace msXpSmineXpert
 
 			if(!canLoadData(m_fileName, this))
 			{
-				qInfo() << __FILE__ << __LINE__ << __FUNCTION__
+				qDebug() << __FILE__ << __LINE__ << __FUNCTION__
 					<< "Could not load the data.";
 
 				return -1;
@@ -1300,9 +1302,16 @@ namespace msXpSmineXpert
 					else if(cvParam.cvid == MS_ms_level)
 					{
 						m_msLevel = cvParam.valueAs<int>();
+
+						//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+						//<< "Current spectrum ms level:" << m_msLevel;
 					}
 				}
 
+				// We do not handle the MS^n scans.
+				if(m_msLevel != 1)
+					continue;
+
 				m_specPeakCount = spectrumPtr->getMZArray()->data.size();
 
 				ScanList scanList = spectrumPtr->scanList;
@@ -1383,10 +1392,10 @@ namespace msXpSmineXpert
 								<< "There are more than one scan window for this spectrum. "
 								"Only handling the first one.";
 					}
-					else if(scanWindowCount == 0)
-						qDebug()
-							<< __FILE__ << __LINE__
-							<< "There is not a single scan window for this spectrum.";
+					//else if(scanWindowCount == 0)
+						//qDebug()
+							//<< __FILE__ << __LINE__
+							//<< "There is not a single scan window for this spectrum.";
 				}
 				// End of
 				// for(uint lter = 0; lter < scanList.scans.size(); ++lter)
@@ -1552,6 +1561,8 @@ namespace msXpSmineXpert
 				// we'll simply delete it after having done the required computation
 				// (to drift time integration or tic intensity, for example).
 				mp_newSpectrum = new msXpSlibmass::MassSpectrum;
+
+				//mp_newSpectrum->Trace::initialize(
 				mp_newSpectrum->initialize(
 						QVector<double>::fromStdVector(mzArrayPtr->data),
 						QVector<double>::fromStdVector(iArrayPtr->data));
@@ -1647,7 +1658,7 @@ namespace msXpSmineXpert
 
 					if(res == -1)
 					{
-						qInfo() << __FILE__ << __LINE__
+						qDebug() << __FILE__ << __LINE__
 							<< "Failed to load a spectrum to vectors.";
 
 						return -1;
@@ -1678,11 +1689,11 @@ namespace msXpSmineXpert
 						// qDebug() << __FILE__ << __LINE__ << "mz integration accounted for:"
 						//<< QString("[%1-%2]\n").arg(mzStart).arg(mzEnd) << "\n";
 
-						m_ticIntensity += mp_newSpectrum->tic(mzStart, mzEnd);
+						m_ticIntensity += mp_newSpectrum->valSum(mzStart, mzEnd);
 
 					}
 					else
-						m_ticIntensity += mp_newSpectrum->tic();
+						m_ticIntensity += mp_newSpectrum->valSum();
 
 					// The spectrum was effectively stored.
 					++m_storedSpectraCount;
@@ -1700,7 +1711,7 @@ namespace msXpSmineXpert
 					//<< "We are transferring the data to the SQLite3 database.";
 
 					// Compute the TIC because we'll need it for the SQL statement below.
-					m_tic = mp_newSpectrum->tic();
+					m_tic = mp_newSpectrum->valSum();
 
 					// Delete the allocated spectrum, because we'll use another mechanism
 					// to feed the database.
@@ -1838,13 +1849,13 @@ namespace msXpSmineXpert
 
 				// qDebug() << __FILE__ << __LINE__
 				// << "For retention time " << keyList.at(iter) << "the tic is: "
-				// << spectrum->tic();
+				// << spectrum->valSum();
 				//}
 			}
 
-			qWarning() << __FILE__ << __LINE__
-				<< "File loading done with a number of stored spectra:" 
-				<< m_storedSpectraCount;
+			//qWarning() << __FILE__ << __LINE__
+				//<< "File loading done with a number of stored spectra:" 
+				//<< m_storedSpectraCount;
 
 			return m_storedSpectraCount;
 		}
@@ -1933,7 +1944,7 @@ namespace msXpSmineXpert
 		\return true if the format of the file can be read by \c this loader.
 
 */
-	bool
+	int 
 		MassSpecDataFileLoaderPwiz::canLoadData(QString fileName,
 				MassSpecDataFileLoaderPwiz *pwiz)
 		{
@@ -1943,9 +1954,10 @@ namespace msXpSmineXpert
 			{
 				qDebug() << __FILE__ << __LINE__ << "Failed to open file" << fileName;
 
-				return false;
+				return MassSpecDataFileFormat::MASS_SPEC_DATA_FILE_FORMAT_NOT_SET;
 			}
-			file.close();
+			else
+				file.close();
 
 			// We use the pwiz facilities to check if it can handle the file at hand.
 			std::string head;
@@ -1963,16 +1975,18 @@ namespace msXpSmineXpert
 			{
 				if(pwiz)
 					pwiz->mp_pwizReader = static_cast<ReaderPtr>(new Reader_mzML);
-				return true;
+
+				return MassSpecDataFileFormat::MASS_SPEC_DATA_FILE_FORMAT_MZML;
 			}
 			else if(cvId == MS_ISB_mzXML_format)
 			{
 				if(pwiz)
 					pwiz->mp_pwizReader = static_cast<ReaderPtr>(new Reader_mzXML);
-				return true;
+
+				return  MassSpecDataFileFormat::MASS_SPEC_DATA_FILE_FORMAT_MZXML;
 			}
 
-			return false;
+			return MassSpecDataFileFormat::MASS_SPEC_DATA_FILE_FORMAT_NOT_SET;
 		}
 
 
