@@ -46,9 +46,9 @@
 
 
 /////////////////////// Local includes
-#include "MassSpecDataFileLoaderSqlite3.hpp"
-#include "globals/globals.hpp"
-#include "History.hpp"
+#include <minexpert/nongui/MassSpecDataFileLoaderSqlite3.hpp>
+#include <globals/globals.hpp>
+#include <minexpert/nongui/History.hpp>
 
 
 namespace msXpSmineXpert
@@ -577,12 +577,8 @@ namespace msXpSmineXpert
 				QByteArray *p_enc64MzByteArray = mzByteArrayList.at(iter);
 				QByteArray *p_enc64IByteArray = iByteArrayList.at(iter);
 
-				// Used for debugging purposes.
-				//msXpSlibmass::MassSpectrum *newSpectrum = msXpSlibmass::MassSpectrum::createFromBase64EncByteArrays(
-				//p_enc64MzByteArray, p_enc64IByteArray, compressionType, 2000, 2400);
-
-				msXpSlibmass::MassSpectrum *newSpectrum = msXpSlibmass::MassSpectrum::createFromBase64EncByteArrays(
-						p_enc64MzByteArray, p_enc64IByteArray, compressionType);
+				msXpSlibmass::MassSpectrum *newSpectrum = new msXpSlibmass::MassSpectrum;
+				newSpectrum->initialize(p_enc64MzByteArray, p_enc64IByteArray, compressionType);
 
 				if(newSpectrum == Q_NULLPTR)
 					qFatal("Fatal error at %s@%d -- %s. "
@@ -590,7 +586,7 @@ namespace msXpSmineXpert
 							"Program aborted.",
 							__FILE__, __LINE__, __FUNCTION__);
 
-				#if 0
+#if 0
 				if(iter == 47)
 				{
 					QFile file1(QString("/tmp/%1-index-%2.enc")
@@ -645,7 +641,7 @@ namespace msXpSmineXpert
 						// This is the chance we have to calculate the TIC for the
 						// spectrum:
 
-						double newTic = newSpectrum->tic();
+						double newTic = newSpectrum->valSum();
 
 						// Had already another spectrum have the same rt ? If so another
 						// TIC was already computed.
@@ -680,28 +676,24 @@ namespace msXpSmineXpert
 
 						if(dataKind == MassDataKind::DRIFT_SPECTRA)
 						{
-							// Let's see if for the current drift time, a spectrum was
-							// already
+
+							// Let's see if for the current drift time, a spectrum was already
 							// encountered (and possibly undergoing combinations).
-							msXpSlibmass::MassSpectrum *massSpectrum =
+
+							msXpSlibmass::Trace *p_trace =
 								massSpecDataSet->m_dtHash.value(dtList.at(iter), nullptr);
 
-							if(massSpectrum == nullptr)
+							if(p_trace == Q_NULLPTR)
 							{
-								// This is the first spectrum that we set to the hash that
-								// has
-								// the current dt value. We want to combine all the
-								// spectra that
-								// have the same dt.
-								// We need to store the spectrum so that we can later
-								// refer to
-								// it, to fill in the colormap. But remember, we want to
-								// make a
-								// calculation such that there are less MassPeak elements
-								// in the
-								// spectra. So we need to allocated a new spectrum and
-								// combine
-								// with rounding (0 decimals) the newSpectrum in it.
+
+								// This is the first spectrum that we set to the hash that has
+								// the current dt value. We want to combine all the spectra that
+								// have the same dt.  We need to store the spectrum so that we
+								// can later refer to it, to fill in the colormap. But remember,
+								// we want to make a calculation such that there are less
+								// MassPeak elements in the spectra. So we need to allocated a
+								// new spectrum and combine with rounding (0 decimals) the
+								// newSpectrum in it.
 
 								msXpSlibmass::MassSpectrum *spectrum = new msXpSlibmass::MassSpectrum;
 								spectrum->rdecimalPlaces() = 0;
@@ -720,12 +712,12 @@ namespace msXpSmineXpert
 								// Finally, let's store the first mz value and the last
 								// one.
 								// Only if the values need an update.
-								double mz_first = spectrum->first()->mz();
+								double mz_first = spectrum->first()->key();
 
 								if(mz_first < massSpecDataSet->m_mzRangeStart)
 									massSpecDataSet->m_mzRangeStart = mz_first;
 
-								double mz_last = spectrum->last()->mz();
+								double mz_last = spectrum->last()->key();
 
 								if(mz_last > massSpecDataSet->m_mzRangeEnd)
 									massSpecDataSet->m_mzRangeEnd = mz_last;
@@ -733,6 +725,7 @@ namespace msXpSmineXpert
 								// We will need to know what is the number of cells on the
 								// mz
 								// axis of the colormap matrix.
+
 								int spectrumSize = spectrum->size();
 
 								if(spectrumSize > massSpecDataSet->m_mzCellCount)
@@ -740,11 +733,12 @@ namespace msXpSmineXpert
 							}
 							else
 							{
-								// We already have inserted a mass spectrum by the current
-								// dt.
+
+								// We already have inserted a mass spectrum by the current dt.
 								// So use it to combine the newly generated one.
-								massSpectrum->rdecimalPlaces() = 0;
-								massSpectrum->combine(*newSpectrum);
+
+								p_trace->rdecimalPlaces() = 0;
+								p_trace->combine(*newSpectrum);
 
 								// Since we do not use this spectrum anymore, we can
 								// delete it.
@@ -753,20 +747,20 @@ namespace msXpSmineXpert
 								// Finally, let's store the first mz value and the last
 								// one.
 								// Only if the values need an update.
-								double mz_first = massSpectrum->first()->mz();
+								double mz_first = p_trace->first()->key();
 
 								if(mz_first < massSpecDataSet->m_mzRangeStart)
 									massSpecDataSet->m_mzRangeStart = mz_first;
 
-								double mz_last = massSpectrum->last()->mz();
+								double mz_last = p_trace->last()->key();
 
 								if(mz_last > massSpecDataSet->m_mzRangeEnd)
 									massSpecDataSet->m_mzRangeEnd = mz_last;
 
-								// We will need to know what is the number of cells on the
-								// mz
+								// We will need to know what is the number of cells on the mz
 								// axis of the colormap matrix.
-								int spectrumSize = massSpectrum->size();
+
+								int spectrumSize = p_trace->size();
 
 								if(spectrumSize > massSpecDataSet->m_mzCellCount)
 									massSpecDataSet->m_mzCellCount = spectrumSize;
@@ -837,7 +831,7 @@ namespace msXpSmineXpert
 */
 	int
 		MassSpecDataFileLoaderSqlite3::loadSpectraByRt(
-				double retentionTime /*scanStartTime */, msXpSlibmass::MassSpectrumList *massSpectra)
+				double retentionTime /*scanStartTime */, QList<msXpSlibmass::MassSpectrum *> *massSpectra)
 		{
 			if(massSpectra == nullptr)
 				qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
@@ -934,8 +928,8 @@ namespace msXpSmineXpert
 				QByteArray *p_enc64MzByteArray = mzByteArrayList.at(iter);
 				QByteArray *p_enc64IByteArray = iByteArrayList.at(iter);
 
-				msXpSlibmass::MassSpectrum *newSpectrum = msXpSlibmass::MassSpectrum::createFromBase64EncByteArrays(
-						p_enc64MzByteArray, p_enc64IByteArray, compressionType);
+				msXpSlibmass::MassSpectrum *newSpectrum = new msXpSlibmass::MassSpectrum;
+				newSpectrum->initialize(p_enc64MzByteArray, p_enc64IByteArray, compressionType);
 
 				// qDebug() << __FILE__ << __LINE__
 				// << "Allocated new spectrum of " << mzList.size() << "peaks";
@@ -1141,8 +1135,8 @@ namespace msXpSmineXpert
 
 				// And now actually perform the data crunching
 
-				msXpSlibmass::MassSpectrum *newSpectrum = msXpSlibmass::MassSpectrum::createFromBase64EncByteArrays(
-						p_enc64MzByteArray, p_enc64IByteArray, compressionType);
+				msXpSlibmass::MassSpectrum *newSpectrum = new msXpSlibmass::MassSpectrum;
+				newSpectrum->initialize(p_enc64MzByteArray, p_enc64IByteArray, compressionType);
 
 				// Free the memory that we do not use anymore.
 				delete p_enc64MzByteArray;
@@ -1159,9 +1153,9 @@ namespace msXpSmineXpert
 				double newTic;
 
 				if(mzIntegration)
-					newTic = newSpectrum->tic(mzStart, mzEnd);
+					newTic = newSpectrum->valSum(mzStart, mzEnd);
 				else
-					newTic = newSpectrum->tic();
+					newTic = newSpectrum->valSum();
 
 				delete newSpectrum;
 
@@ -1387,8 +1381,8 @@ namespace msXpSmineXpert
 
 				// And now actually perform the data crunching
 
-				msXpSlibmass::MassSpectrum *newSpectrum = msXpSlibmass::MassSpectrum::createFromBase64EncByteArrays(
-						p_enc64MzByteArray, p_enc64IByteArray, compressionType);
+				msXpSlibmass::MassSpectrum *newSpectrum = new msXpSlibmass::MassSpectrum;
+				newSpectrum->initialize(p_enc64MzByteArray, p_enc64IByteArray, compressionType);
 
 				// Free the memory that we do not use anymore.
 				delete p_enc64MzByteArray;
@@ -1420,8 +1414,8 @@ namespace msXpSmineXpert
 
 			// Now actually set the values to the vectors passed as parameter.
 
-			*keyVector = QVector<double>::fromList(combinedMassSpectrum.mzList());
-			*valVector = QVector<double>::fromList(combinedMassSpectrum.iList());
+			*keyVector = QVector<double>::fromList(combinedMassSpectrum.keyList());
+			*valVector = QVector<double>::fromList(combinedMassSpectrum.valList());
 
 			return spectraRead;
 		}
@@ -1605,8 +1599,8 @@ namespace msXpSmineXpert
 
 				// And now actually perform the data crunching
 
-				msXpSlibmass::MassSpectrum *newSpectrum = msXpSlibmass::MassSpectrum::createFromBase64EncByteArrays(
-						p_enc64MzByteArray, p_enc64IByteArray, compressionType);
+				msXpSlibmass::MassSpectrum *newSpectrum = new msXpSlibmass::MassSpectrum;
+				newSpectrum->initialize(p_enc64MzByteArray, p_enc64IByteArray, compressionType);
 
 				// Free the memory that we do not use anymore.
 				delete p_enc64MzByteArray;
@@ -1622,9 +1616,9 @@ namespace msXpSmineXpert
 				double newTic;
 
 				if(mzIntegration)
-					newTic = newSpectrum->tic(mzStart, mzEnd);
+					newTic = newSpectrum->valSum(mzStart, mzEnd);
 				else
-					newTic = newSpectrum->tic();
+					newTic = newSpectrum->valSum();
 
 				delete newSpectrum;
 
@@ -1873,8 +1867,8 @@ namespace msXpSmineXpert
 
 			emit dataLoadMessageSignal(msg, LOG_TO_BOTH);
 
-			qDebug() << __FILE__ << __LINE__
-				<< "Loading data: total number of spectra to load:" << m_spectrumCount;
+			//qDebug() << __FILE__ << __LINE__
+				//<< "Loading data: total number of spectra to load:" << m_spectrumCount;
 
 			// The way this function works is that is loads the spectra at positions
 			// firstId to lastId in the spectralData table. Each time a new spectrum
@@ -1893,9 +1887,8 @@ namespace msXpSmineXpert
 			{
 				if(m_isOperationCancelled)
 				{
-					qDebug() << __FILE__ << __LINE__ << "Going to break while loop due "
-						"to abort requested by the "
-						"user.";
+					qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+						<< "Going to break while loop due to abort requested by the user.";
 
 					break;
 				}
@@ -2182,8 +2175,8 @@ namespace msXpSmineXpert
 
 				// And now actually perform the data crunching
 
-				msXpSlibmass::MassSpectrum *newSpectrum = msXpSlibmass::MassSpectrum::createFromBase64EncByteArrays(
-						p_enc64MzByteArray, p_enc64IByteArray, compressionType);
+				msXpSlibmass::MassSpectrum *newSpectrum = new msXpSlibmass::MassSpectrum;
+				newSpectrum->initialize(p_enc64MzByteArray, p_enc64IByteArray, compressionType);
 
 				// Free the memory that we do not use anymore.
 				delete p_enc64MzByteArray;
@@ -2197,9 +2190,9 @@ namespace msXpSmineXpert
 				// mass spectrum data.
 
 				if(mzIntegration)
-					localIntensity += newSpectrum->tic(mzStart, mzEnd);
+					localIntensity += newSpectrum->valSum(mzStart, mzEnd);
 				else
-					localIntensity += newSpectrum->tic();
+					localIntensity += newSpectrum->valSum();
 
 				delete newSpectrum;
 
