@@ -46,8 +46,8 @@
 
 
 /////////////////////// Local includes
-#include "MassSpecSqlite3Handler.hpp"
-#include "History.hpp"
+#include <minexpert/nongui/MassSpecSqlite3Handler.hpp>
+#include <minexpert/nongui/History.hpp>
 
 
 namespace msXpSmineXpert
@@ -1741,7 +1741,7 @@ namespace msXpSmineXpert
 		}
 
 
-	//! Export data from \c this \m_db to a database in file \p fileName.
+	//! Export data from \c this \c m_db to a database in file \p fileName.
 	/*!
 
 		The criteria on which data are selected from \c this \c m_db database are
