@@ -41,7 +41,7 @@
 
 
 /////////////////////// Local includes
-#include "SqlMassDataSlicer.hpp"
+#include <minexpert/nongui/SqlMassDataSlicer.hpp>
 
 
 namespace msXpSmineXpert
