@@ -1,4 +1,4 @@
 #define CATCH_CONFIG_MAIN // This tells Catch to provide a main() - only do
                           // this in one cpp file
-#include "catch.hpp"
+#include <catch.hpp>
 
